@@ -15,23 +15,6 @@ def raise_error_callback(exception, traceback, automl, **kwargs):
     raise exception
 
 
-def log_and_save_error_callback(exception, traceback, automl, **kwargs):
-    """Logs the exception thrown by the AutoMLSearch object as a warning
-        and adds the exception to the 'errors' list in AutoMLSearch object results."""
-    logger.warning(f'AutoML search encountered an exception: {str(exception)}')
-    logger.warning("\n".join(traceback))
-    automl._results['errors'].append(exception)
-
-
-def raise_and_save_error_callback(exception, traceback, automl, **kwargs):
-    """Raises the exception thrown by the AutoMLSearch object, logs it as an error,
-        and adds the exception to the 'errors' list in AutoMLSearch object results."""
-    logger.error(f'AutoML search raised a fatal exception: {str(exception)}')
-    logger.error("\n".join(traceback))
-    automl._results['errors'].append(exception)
-    raise exception
-
-
 def log_error_callback(exception, traceback, automl, **kwargs):
     """Logs the exception thrown as an error. Will not throw. This is the default behavior for AutoMLSearch."""
     fold_num = kwargs.get('fold_num')
