@@ -3,7 +3,6 @@ from .exceptions import (
     MethodPropertyNotFoundError,
     PipelineNotFoundError,
     ObjectiveNotFoundError,
-    IllFormattedClassNameError,
     MissingComponentError,
     ComponentNotYetFittedError,
     PipelineNotYetFittedError,
@@ -11,5 +10,7 @@ from .exceptions import (
     PipelineScoreError,
     DataCheckInitError,
     EnsembleMissingPipelinesError,
-    NullsInColumnWarning
+    NullsInColumnWarning,
+    ObjectiveCreationError,
+    NoPositiveLabelException
 )
