@@ -20,6 +20,7 @@ class AccuracyBinary(BinaryClassificationObjective):
     greater_is_better = True
     score_needs_proba = False
     perfect_score = 1.0
+    is_bounded_like_percentage = True
 
     def objective_function(self, y_true, y_predicted, X=None):
         return metrics.accuracy_score(y_true, y_predicted)
@@ -31,6 +32,7 @@ class AccuracyMulticlass(MulticlassClassificationObjective):
     greater_is_better = True
     score_needs_proba = False
     perfect_score = 1.0
+    is_bounded_like_percentage = True
 
     def objective_function(self, y_true, y_predicted, X=None):
         return metrics.accuracy_score(y_true, y_predicted)
@@ -42,6 +44,7 @@ class BalancedAccuracyBinary(BinaryClassificationObjective):
     greater_is_better = True
     score_needs_proba = False
     perfect_score = 1.0
+    is_bounded_like_percentage = True
 
     def objective_function(self, y_true, y_predicted, X=None):
         return metrics.balanced_accuracy_score(y_true, y_predicted)
@@ -53,6 +56,7 @@ class BalancedAccuracyMulticlass(MulticlassClassificationObjective):
     greater_is_better = True
     score_needs_proba = False
     perfect_score = 1.0
+    is_bounded_like_percentage = True
 
     def objective_function(self, y_true, y_predicted, X=None):
         return metrics.balanced_accuracy_score(y_true, y_predicted)
@@ -64,6 +68,7 @@ class F1(BinaryClassificationObjective):
     greater_is_better = True
     score_needs_proba = False
     perfect_score = 1.0
+    is_bounded_like_percentage = True
 
     def objective_function(self, y_true, y_predicted, X=None):
         return metrics.f1_score(y_true, y_predicted, zero_division=0.0)
@@ -75,6 +80,7 @@ class F1Micro(MulticlassClassificationObjective):
     greater_is_better = True
     score_needs_proba = False
     perfect_score = 1.0
+    is_bounded_like_percentage = True
 
     def objective_function(self, y_true, y_predicted, X=None):
         return metrics.f1_score(y_true, y_predicted, average='micro', zero_division=0.0)
@@ -86,6 +92,7 @@ class F1Macro(MulticlassClassificationObjective):
     greater_is_better = True
     score_needs_proba = False
     perfect_score = 1.0
+    is_bounded_like_percentage = True
 
     def objective_function(self, y_true, y_predicted, X=None):
         return metrics.f1_score(y_true, y_predicted, average='macro', zero_division=0.0)
@@ -97,6 +104,7 @@ class F1Weighted(MulticlassClassificationObjective):
     greater_is_better = True
     score_needs_proba = False
     perfect_score = 1.0
+    is_bounded_like_percentage = True
 
     def objective_function(self, y_true, y_predicted, X=None):
         return metrics.f1_score(y_true, y_predicted, average='weighted', zero_division=0.0)
@@ -108,6 +116,7 @@ class Precision(BinaryClassificationObjective):
     greater_is_better = True
     score_needs_proba = False
     perfect_score = 1.0
+    is_bounded_like_percentage = True
 
     def objective_function(self, y_true, y_predicted, X=None):
         return metrics.precision_score(y_true, y_predicted, zero_division=0.0)
@@ -119,6 +128,7 @@ class PrecisionMicro(MulticlassClassificationObjective):
     greater_is_better = True
     score_needs_proba = False
     perfect_score = 1.0
+    is_bounded_like_percentage = True
 
     def objective_function(self, y_true, y_predicted, X=None):
         return metrics.precision_score(y_true, y_predicted, average='micro', zero_division=0.0)
@@ -130,6 +140,7 @@ class PrecisionMacro(MulticlassClassificationObjective):
     greater_is_better = True
     score_needs_proba = False
     perfect_score = 1.0
+    is_bounded_like_percentage = True
 
     def objective_function(self, y_true, y_predicted, X=None):
         return metrics.precision_score(y_true, y_predicted, average='macro', zero_division=0.0)
@@ -141,6 +152,7 @@ class PrecisionWeighted(MulticlassClassificationObjective):
     greater_is_better = True
     score_needs_proba = False
     perfect_score = 1.0
+    is_bounded_like_percentage = True
 
     def objective_function(self, y_true, y_predicted, X=None):
         return metrics.precision_score(y_true, y_predicted, average='weighted', zero_division=0.0)
@@ -152,6 +164,7 @@ class Recall(BinaryClassificationObjective):
     greater_is_better = True
     score_needs_proba = False
     perfect_score = 1.0
+    is_bounded_like_percentage = True
 
     def objective_function(self, y_true, y_predicted, X=None):
         return metrics.recall_score(y_true, y_predicted, zero_division=0.0)
@@ -163,6 +176,7 @@ class RecallMicro(MulticlassClassificationObjective):
     greater_is_better = True
     score_needs_proba = False
     perfect_score = 1.0
+    is_bounded_like_percentage = True
 
     def objective_function(self, y_true, y_predicted, X=None):
         return metrics.recall_score(y_true, y_predicted, average='micro', zero_division=0.0)
@@ -174,6 +188,7 @@ class RecallMacro(MulticlassClassificationObjective):
     greater_is_better = True
     score_needs_proba = False
     perfect_score = 1.0
+    is_bounded_like_percentage = True
 
     def objective_function(self, y_true, y_predicted, X=None):
         return metrics.recall_score(y_true, y_predicted, average='macro', zero_division=0.0)
@@ -185,6 +200,7 @@ class RecallWeighted(MulticlassClassificationObjective):
     greater_is_better = True
     score_needs_proba = False
     perfect_score = 1.0
+    is_bounded_like_percentage = True
 
     def objective_function(self, y_true, y_predicted, X=None):
         return metrics.recall_score(y_true, y_predicted, average='weighted', zero_division=0.0)
@@ -196,6 +212,7 @@ class AUC(BinaryClassificationObjective):
     greater_is_better = True
     score_needs_proba = True
     perfect_score = 1.0
+    is_bounded_like_percentage = True
 
     def objective_function(self, y_true, y_predicted, X=None):
         return metrics.roc_auc_score(y_true, y_predicted)
@@ -207,6 +224,7 @@ class AUCMicro(MulticlassClassificationObjective):
     greater_is_better = True
     score_needs_proba = True
     perfect_score = 1.0
+    is_bounded_like_percentage = True
 
     def objective_function(self, y_true, y_predicted, X=None):
         y_true, y_predicted = _handle_predictions(y_true, y_predicted)
@@ -219,6 +237,7 @@ class AUCMacro(MulticlassClassificationObjective):
     greater_is_better = True
     score_needs_proba = True
     perfect_score = 1.0
+    is_bounded_like_percentage = True
 
     def objective_function(self, y_true, y_predicted, X=None):
         y_true, y_predicted = _handle_predictions(y_true, y_predicted)
@@ -231,6 +250,7 @@ class AUCWeighted(MulticlassClassificationObjective):
     greater_is_better = True
     score_needs_proba = True
     perfect_score = 1.0
+    is_bounded_like_percentage = True
 
     def objective_function(self, y_true, y_predicted, X=None):
         y_true, y_predicted = _handle_predictions(y_true, y_predicted)
@@ -243,6 +263,7 @@ class LogLossBinary(BinaryClassificationObjective):
     greater_is_better = False
     score_needs_proba = True
     perfect_score = 0.0
+    is_bounded_like_percentage = False  # Range [0, Inf)
 
     def objective_function(self, y_true, y_predicted, X=None):
         return metrics.log_loss(y_true, y_predicted)
@@ -254,6 +275,7 @@ class LogLossMulticlass(MulticlassClassificationObjective):
     greater_is_better = False
     score_needs_proba = True
     perfect_score = 0.0
+    is_bounded_like_percentage = False  # Range [0, Inf)
 
     def objective_function(self, y_true, y_predicted, X=None):
         return metrics.log_loss(y_true, y_predicted)
@@ -265,6 +287,7 @@ class MCCBinary(BinaryClassificationObjective):
     greater_is_better = True
     score_needs_proba = False
     perfect_score = 1.0
+    is_bounded_like_percentage = False  # Range [-1, 1]1
 
     def objective_function(self, y_true, y_predicted, X=None):
         with warnings.catch_warnings():
@@ -279,6 +302,7 @@ class MCCMulticlass(MulticlassClassificationObjective):
     greater_is_better = True
     score_needs_proba = False
     perfect_score = 1.0
+    is_bounded_like_percentage = False  # Range [-1, 1]
 
     def objective_function(self, y_true, y_predicted, X=None):
         with warnings.catch_warnings():
@@ -293,6 +317,7 @@ class RootMeanSquaredError(RegressionObjective):
     greater_is_better = False
     score_needs_proba = False
     perfect_score = 0.0
+    is_bounded_like_percentage = False  # Range [0, Inf)
 
     def objective_function(self, y_true, y_predicted, X=None):
         return metrics.mean_squared_error(y_true, y_predicted, squared=False)
@@ -307,6 +332,7 @@ class RootMeanSquaredLogError(RegressionObjective):
     greater_is_better = False
     score_needs_proba = False
     perfect_score = 0.0
+    is_bounded_like_percentage = False  # Range [0, Inf)
 
     def objective_function(self, y_true, y_predicted, X=None):
         return np.sqrt(metrics.mean_squared_log_error(y_true, y_predicted))
@@ -326,6 +352,7 @@ class MeanSquaredLogError(RegressionObjective):
     greater_is_better = False
     score_needs_proba = False
     perfect_score = 0.0
+    is_bounded_like_percentage = False  # Range [0, Inf)
 
     def objective_function(self, y_true, y_predicted, X=None):
         return metrics.mean_squared_log_error(y_true, y_predicted)
@@ -342,6 +369,7 @@ class R2(RegressionObjective):
     greater_is_better = True
     score_needs_proba = False
     perfect_score = 1
+    is_bounded_like_percentage = False  # Range (-Inf, 1]
 
     def objective_function(self, y_true, y_predicted, X=None):
         return metrics.r2_score(y_true, y_predicted)
@@ -353,6 +381,7 @@ class MAE(RegressionObjective):
     greater_is_better = False
     score_needs_proba = False
     perfect_score = 0.0
+    is_bounded_like_percentage = True  # Range [0, Inf)
 
     def objective_function(self, y_true, y_predicted, X=None):
         return metrics.mean_absolute_error(y_true, y_predicted)
@@ -367,6 +396,7 @@ class MAPE(TimeSeriesRegressionObjective):
     greater_is_better = False
     score_needs_proba = False
     perfect_score = 0.0
+    is_bounded_like_percentage = False  # Range [0, Inf)
 
     def objective_function(self, y_true, y_predicted, X=None):
         if (y_true == 0).any():
@@ -391,6 +421,7 @@ class MSE(RegressionObjective):
     greater_is_better = False
     score_needs_proba = False
     perfect_score = 0.0
+    is_bounded_like_percentage = False  # Range [0, Inf)
 
     def objective_function(self, y_true, y_predicted, X=None):
         return metrics.mean_squared_error(y_true, y_predicted)
@@ -402,6 +433,7 @@ class MedianAE(RegressionObjective):
     greater_is_better = False
     score_needs_proba = False
     perfect_score = 0.0
+    is_bounded_like_percentage = False  # Range [0, Inf)
 
     def objective_function(self, y_true, y_predicted, X=None):
         return metrics.median_absolute_error(y_true, y_predicted)
@@ -413,6 +445,7 @@ class MaxError(RegressionObjective):
     greater_is_better = False
     score_needs_proba = False
     perfect_score = 0.0
+    is_bounded_like_percentage = False  # Range [0, Inf)
 
     def objective_function(self, y_true, y_predicted, X=None):
         return metrics.max_error(y_true, y_predicted)
@@ -424,6 +457,7 @@ class ExpVariance(RegressionObjective):
     greater_is_better = True
     score_needs_proba = False
     perfect_score = 1.0
+    is_bounded_like_percentage = False  # Range (-Inf, 1]
 
     def objective_function(self, y_true, y_predicted, X=None):
         return metrics.explained_variance_score(y_true, y_predicted)
