@@ -4,7 +4,6 @@ from skopt.space import Integer
 from evalml.model_family import ModelFamily
 from evalml.pipelines.components.estimators import Estimator
 from evalml.problem_types import ProblemTypes
-from evalml.utils import deprecate_arg
 
 
 class DecisionTreeClassifier(Estimator):
@@ -25,7 +24,6 @@ class DecisionTreeClassifier(Estimator):
                  max_depth=6,
                  min_samples_split=2,
                  min_weight_fraction_leaf=0.0,
-                 random_state=None,
                  random_seed=0,
                  **kwargs):
         parameters = {"criterion": criterion,
@@ -34,7 +32,6 @@ class DecisionTreeClassifier(Estimator):
                       "min_samples_split": min_samples_split,
                       "min_weight_fraction_leaf": min_weight_fraction_leaf}
         parameters.update(kwargs)
-        random_seed = deprecate_arg("random_state", "random_seed", random_state, random_seed)
         dt_classifier = SKDecisionTreeClassifier(random_state=random_seed,
                                                  **parameters)
         super().__init__(parameters=parameters,
