@@ -5,7 +5,6 @@ from skopt.space import Real
 from evalml.model_family import ModelFamily
 from evalml.pipelines.components.estimators import Estimator
 from evalml.problem_types import ProblemTypes
-from evalml.utils import deprecate_arg
 
 
 class LogisticRegressionClassifier(Estimator):
@@ -21,15 +20,13 @@ class LogisticRegressionClassifier(Estimator):
     supported_problem_types = [ProblemTypes.BINARY, ProblemTypes.MULTICLASS,
                                ProblemTypes.TIME_SERIES_BINARY, ProblemTypes.TIME_SERIES_MULTICLASS]
 
-    def __init__(self, penalty="l2", C=1.0, n_jobs=-1, multi_class="auto", solver="lbfgs", random_state=None,
-                 random_seed=0, **kwargs):
+    def __init__(self, penalty="l2", C=1.0, n_jobs=-1, multi_class="auto", solver="lbfgs", random_seed=0, **kwargs):
         parameters = {"penalty": penalty,
                       "C": C,
                       "n_jobs": n_jobs,
                       "multi_class": multi_class,
                       "solver": solver}
         parameters.update(kwargs)
-        random_seed = deprecate_arg("random_state", "random_seed", random_state, random_seed)
         lr_classifier = LogisticRegression(random_state=random_seed,
                                            **parameters)
         super().__init__(parameters=parameters,
