@@ -5,7 +5,6 @@ from skopt.space import Real
 from evalml.model_family import ModelFamily
 from evalml.pipelines.components.estimators import Estimator
 from evalml.problem_types import ProblemTypes
-from evalml.utils import deprecate_arg
 
 
 class SVMClassifier(Estimator):
@@ -25,7 +24,6 @@ class SVMClassifier(Estimator):
                  kernel="rbf",
                  gamma="scale",
                  probability=True,
-                 random_state=None,
                  random_seed=0,
                  **kwargs):
         parameters = {"C": C,
@@ -33,7 +31,6 @@ class SVMClassifier(Estimator):
                       "gamma": gamma,
                       "probability": probability}
         parameters.update(kwargs)
-        random_seed = deprecate_arg("random_state", "random_seed", random_state, random_seed)
         svm_classifier = SVC(random_state=random_seed,
                              **parameters)
         super().__init__(parameters=parameters,
