@@ -48,7 +48,7 @@ class CatBoostRegressor(Estimator):
 
     def fit(self, X, y=None):
         X = infer_feature_types(X)
-        cat_cols = list(X.select('category').columns)
+        cat_cols = list(X.ww.select('category').columns)
         self.input_feature_names = list(X.columns)
         X, y = super()._manage_woodwork(X, y)
         self._component_obj.fit(X, y, silent=True, cat_features=cat_cols)
