@@ -3,7 +3,7 @@ from .encoders import OneHotEncoder, TargetEncoder
 from .feature_selection import FeatureSelector, RFClassifierSelectFromModel, RFRegressorSelectFromModel
 from .imputers import PerColumnImputer, SimpleImputer, Imputer, TargetImputer
 from .scalers import StandardScaler
-from .samplers import Undersampler
+from .samplers import Undersampler, SMOTESampler, SMOTENCSampler, SMOTENSampler
 from .column_selectors import DropColumns, SelectColumns
 from .dimensionality_reduction import LinearDiscriminantAnalysis, PCA
 from .preprocessing import DateTimeFeaturizer, DropNullColumns, LSA, TextFeaturizer, DelayedFeatureTransformer, DFSTransformer, PolynomialDetrender
