@@ -3,7 +3,6 @@ from sklearn.discriminant_analysis import LinearDiscriminantAnalysis as SkLDA
 
 from evalml.pipelines.components.transformers import Transformer
 from evalml.utils import (
-    _convert_woodwork_types_wrapper,
     _retain_custom_types_and_initalize_woodwork,
     infer_feature_types,
     is_all_numeric
@@ -36,8 +35,6 @@ class LinearDiscriminantAnalysis(Transformer):
         if not is_all_numeric(X):
             raise ValueError("LDA input must be all numeric")
         y = infer_feature_types(y)
-        X = _convert_woodwork_types_wrapper(X.to_dataframe())
-        y = _convert_woodwork_types_wrapper(y.to_series())
         n_features = X.shape[1]
         n_classes = y.nunique()
         n_components = self.parameters['n_components']
@@ -51,9 +48,8 @@ class LinearDiscriminantAnalysis(Transformer):
         X_ww = infer_feature_types(X)
         if not is_all_numeric(X_ww):
             raise ValueError("LDA input must be all numeric")
-        X = _convert_woodwork_types_wrapper(X_ww.to_dataframe())
         X_t = self._component_obj.transform(X)
-        X_t = pd.DataFrame(X_t, index=X.index, columns=[f"component_{i}" for i in range(X_t.shape[1])])
+        X_t = pd.DataFrame(X_t, index=X_ww.index, columns=[f"component_{i}" for i in range(X_t.shape[1])])
         return _retain_custom_types_and_initalize_woodwork(X_ww, X_t)
 
     def fit_transform(self, X, y=None):
@@ -61,9 +57,7 @@ class LinearDiscriminantAnalysis(Transformer):
         if not is_all_numeric(X_ww):
             raise ValueError("LDA input must be all numeric")
         y = infer_feature_types(y)
-        X = _convert_woodwork_types_wrapper(X_ww.to_dataframe())
-        y = _convert_woodwork_types_wrapper(y.to_series())
 
         X_t = self._component_obj.fit_transform(X, y)
-        X_t = pd.DataFrame(X_t, index=X.index, columns=[f"component_{i}" for i in range(X_t.shape[1])])
+        X_t = pd.DataFrame(X_t, index=X_ww.index, columns=[f"component_{i}" for i in range(X_t.shape[1])])
         return _retain_custom_types_and_initalize_woodwork(X_ww, X_t)
