@@ -1,9 +1,9 @@
 import pandas as pd
 from sklearn.impute import SimpleImputer as SkImputer
+from woodwork.logical_types import NaturalLanguage
 
 from evalml.pipelines.components.transformers import Transformer
 from evalml.utils import (
-    _convert_woodwork_types_wrapper,
     _retain_custom_types_and_initalize_woodwork,
     infer_feature_types
 )
@@ -40,59 +40,67 @@ class SimpleImputer(Transformer):
             treated as the same.
 
         Arguments:
-            X (ww.DataTable, pd.DataFrame or np.ndarray): the input training data of shape [n_samples, n_features]
-            y (ww.DataColumn, pd.Series, optional): the target training data of length [n_samples]
+            X (pd.DataFrame or np.ndarray): the input training data of shape [n_samples, n_features]
+            y (pd.Series, optional): the target training data of length [n_samples]
 
         Returns:
             self
         """
         X = infer_feature_types(X)
-        X = _convert_woodwork_types_wrapper(X.to_dataframe())
+        nan_ratio = X.ww.describe().loc['nan_count'] / X.shape[0]
+        self._all_null_cols = nan_ratio[nan_ratio == 1].index.tolist()
+
+        # Not using select because we just need column names, not a new dataframe
+        natural_language_columns = [col for col, ltype in X.ww.logical_types.items() if ltype == NaturalLanguage]
+        if natural_language_columns:
+            X = X.ww.copy()
+            X.ww.set_types({col: "Categorical" for col in natural_language_columns})
 
         # Convert all bool dtypes to category for fitting
         if (X.dtypes == bool).all():
             X = X.astype('category')
 
         self._component_obj.fit(X, y)
-        self._all_null_cols = set(X.columns) - set(X.dropna(axis=1, how='all').columns)
         return self
 
     def transform(self, X, y=None):
         """Transforms input by imputing missing values. 'None' and np.nan values are treated as the same.
 
         Arguments:
-            X (ww.DataTable, pd.DataFrame): Data to transform
-            y (ww.DataColumn, pd.Series, optional): Ignored.
+            X (pd.DataFrame): Data to transform
+            y (pd.Series, optional): Ignored.
 
         Returns:
-            ww.DataTable: Transformed X
+            pd.DataFrame: Transformed X
         """
-        X_ww = infer_feature_types(X)
-        X = _convert_woodwork_types_wrapper(X_ww.to_dataframe())
+        X = infer_feature_types(X)
+        original_logical_types = X.ww.schema.logical_types
 
         # Return early since bool dtype doesn't support nans and sklearn errors if all cols are bool
         if (X.dtypes == bool).all():
-            return infer_feature_types(X)
+            return X
 
-        X_null_dropped = X.copy()
-        X_null_dropped.drop(self._all_null_cols, axis=1, errors='ignore', inplace=True)
-        X_t = self._component_obj.transform(X)
-        if X_null_dropped.empty:
-            X_t = pd.DataFrame(X_t, columns=X_null_dropped.columns)
-            return infer_feature_types(X_t)
+        not_all_null_cols = [col for col in X.columns if col not in self._all_null_cols]
+        original_index = X.index
 
-        X_t = pd.DataFrame(X_t, columns=X_null_dropped.columns)
-        X_t.index = X_null_dropped.index
-        return _retain_custom_types_and_initalize_woodwork(X_ww, X_t)
+        # Not using select because we just need column names, not a new dataframe
+        X.ww.set_types({col: "Categorical" for col, ltype in X.ww.logical_types.items() if ltype == NaturalLanguage})
+
+        X = self._component_obj.transform(X)
+        X = pd.DataFrame(X, columns=not_all_null_cols)
+        if not_all_null_cols:
+            X.index = original_index
+
+        return _retain_custom_types_and_initalize_woodwork(original_logical_types, X)
 
     def fit_transform(self, X, y=None):
         """Fits on X and transforms X
 
         Arguments:
-            X (ww.DataTable, pd.DataFrame): Data to fit and transform
-            y (ww.DataColumn, pd.Series, optional): Target data.
+            X (pd.DataFrame): Data to fit and transform
+            y (pd.Series, optional): Target data.
 
         Returns:
-            ww.DataTable: Transformed X
+            pd.DataFrame: Transformed X
         """
         return self.fit(X, y).transform(X, y)
