@@ -10,11 +10,7 @@ from evalml.pipelines.components.component_base import ComponentBase
 from evalml.pipelines.components.estimators.estimator import Estimator
 from evalml.pipelines.components.transformers.transformer import Transformer
 from evalml.problem_types import ProblemTypes, handle_problem_types
-from evalml.utils import (
-    _convert_woodwork_types_wrapper,
-    get_importable_subclasses,
-    get_logger
-)
+from evalml.utils import get_importable_subclasses, get_logger
 
 logger = get_logger(__file__)
 
@@ -151,25 +147,25 @@ class WrappedSKClassifier(BaseEstimator, ClassifierMixin):
         """Make predictions using selected features.
 
         Arguments:
-            X (ww.DataTable, pd.DataFrame): Features
+            X (pd.DataFrame): Features
 
         Returns:
             np.ndarray: Predicted values
         """
         check_is_fitted(self, 'is_fitted_')
 
-        return _convert_woodwork_types_wrapper(self.pipeline.predict(X).to_series()).to_numpy()
+        return self.pipeline.predict(X).to_numpy()
 
     def predict_proba(self, X):
         """Make probability estimates for labels.
 
         Arguments:
-            X (ww.DataTable, pd.DataFrame): Features
+            X (pd.DataFrame): Features
 
         Returns:
             np.ndarray: Probability estimates
         """
-        return _convert_woodwork_types_wrapper(self.pipeline.predict_proba(X).to_dataframe()).to_numpy()
+        return self.pipeline.predict_proba(X).to_numpy()
 
 
 class WrappedSKRegressor(BaseEstimator, RegressorMixin):
@@ -192,8 +188,8 @@ class WrappedSKRegressor(BaseEstimator, RegressorMixin):
         """Fits component to data
 
         Arguments:
-            X (ww.DataTable, pd.DataFrame or np.ndarray): the input training data of shape [n_samples, n_features]
-            y (ww.DataColumn, pd.Series, optional): the target training data of length [n_samples]
+            X (pd.DataFrame or np.ndarray): the input training data of shape [n_samples, n_features]
+            y (pd.Series, optional): the target training data of length [n_samples]
 
         Returns:
             self
@@ -205,12 +201,12 @@ class WrappedSKRegressor(BaseEstimator, RegressorMixin):
         """Make predictions using selected features.
 
         Arguments:
-            X (ww.DataTable, pd.DataFrame): Features
+            X (pd.DataFrame): Features
 
         Returns:
             np.ndarray: Predicted values
         """
-        return self.pipeline.predict(X).to_series().to_numpy()
+        return self.pipeline.predict(X).to_numpy()
 
 
 def scikit_learn_wrapped_estimator(evalml_obj):
