@@ -52,8 +52,8 @@ def _get_preprocessing_components(X, y, problem_type, estimator_class, sampler_n
     """Given input data, target data and an estimator class, construct a recommended preprocessing chain to be combined with the estimator and trained on the provided data.
 
     Arguments:
-        X (ww.DataTable): The input data of shape [n_samples, n_features]
-        y (ww.DataColumn): The target data of length [n_samples]
+        X (pd.DataFrame): The input data of shape [n_samples, n_features]
+        y (pd.Series): The target data of length [n_samples]
         problem_type (ProblemTypes or str): Problem type
         estimator_class (class): A class which subclasses Estimator estimator for pipeline,
         sampler_name (str): The name of the sampler component to add to the pipeline. Defaults to None
@@ -62,25 +62,26 @@ def _get_preprocessing_components(X, y, problem_type, estimator_class, sampler_n
         list[Transformer]: A list of applicable preprocessing components to use with the estimator
     """
 
-    X_pd = X.to_dataframe()
     pp_components = []
-    all_null_cols = X_pd.columns[X_pd.isnull().all()]
+    all_null_cols = X.columns[X.isnull().all()]
     if len(all_null_cols) > 0:
         pp_components.append(DropNullColumns)
-    input_logical_types = set(X.logical_types.values())
-    types_imputer_handles = {logical_types.Boolean, logical_types.Categorical, logical_types.Double, logical_types.Integer}
+    input_logical_types = set(X.ww.logical_types.values())
+    types_imputer_handles = {logical_types.Boolean, logical_types.Categorical,
+                             logical_types.Double, logical_types.Integer}
     if len(input_logical_types.intersection(types_imputer_handles)) > 0:
         pp_components.append(Imputer)
 
-    text_columns = list(X.select('natural_language').columns)
+    text_columns = list(X.ww.select('NaturalLanguage').columns)
     if len(text_columns) > 0:
         pp_components.append(TextFeaturizer)
 
-    index_columns = list(X.select('index').columns)
+    index_columns = list(X.ww.select('index').columns)
     if len(index_columns) > 0:
         pp_components.append(DropColumns)
 
-    datetime_cols = X.select(["Datetime"])
+    datetime_cols = X.ww.select(["Datetime"])
+
     add_datetime_featurizer = len(datetime_cols.columns) > 0
     if add_datetime_featurizer and estimator_class.model_family != ModelFamily.ARIMA:
         pp_components.append(DateTimeFeaturizer)
@@ -88,7 +89,7 @@ def _get_preprocessing_components(X, y, problem_type, estimator_class, sampler_n
     if is_time_series(problem_type) and estimator_class.model_family != ModelFamily.ARIMA:
         pp_components.append(DelayedFeatureTransformer)
 
-    categorical_cols = X.select('category')
+    categorical_cols = X.ww.select('category')
     if len(categorical_cols.columns) > 0 and estimator_class not in {CatBoostClassifier, CatBoostRegressor}:
         pp_components.append(OneHotEncoder)
 
@@ -134,8 +135,8 @@ def make_pipeline(X, y, estimator, problem_type, parameters=None, custom_hyperpa
         The pipeline will be a subclass of the appropriate pipeline base class for the specified problem_type.
 
    Arguments:
-        X (pd.DataFrame, ww.DataTable): The input data of shape [n_samples, n_features]
-        y (pd.Series, ww.DataColumn): The target data of length [n_samples]
+        X (pd.DataFrame): The input data of shape [n_samples, n_features]
+        y (pd.Series): The target data of length [n_samples]
         estimator (Estimator): Estimator for pipeline
         problem_type (ProblemTypes or str): Problem type for pipeline to generate
         parameters (dict): Dictionary with component names as keys and dictionary of that component's parameters as values.
