@@ -37,14 +37,14 @@ def test_baseline_binary_mode(data_type, make_data_type):
     fitted = clf.fit(X, y)
     assert isinstance(fitted, BaselineClassifier)
     assert clf.classes_ == [10, 11]
-    expected_predictions = pd.Series(np.array([10] * X.shape[0]), dtype="Int64")
+    expected_predictions = pd.Series(np.array([10] * X.shape[0]), dtype="int64")
     predictions = clf.predict(X)
-    assert_series_equal(expected_predictions, predictions.to_series())
+    assert_series_equal(expected_predictions, predictions)
 
     predicted_proba = clf.predict_proba(X)
     assert predicted_proba.shape == (X.shape[0], 2)
     expected_predictions_proba = pd.DataFrame({10: [1., 1., 1., 1.], 11: [0., 0., 0., 0.]})
-    assert_frame_equal(expected_predictions_proba, predicted_proba.to_dataframe())
+    assert_frame_equal(expected_predictions_proba, predicted_proba)
 
     np.testing.assert_allclose(clf.feature_importance, np.array([0.0] * X.shape[1]))
 
@@ -56,14 +56,14 @@ def test_baseline_binary_random(X_y_binary):
     clf.fit(X, y)
     assert clf.classes_ == [0, 1]
 
-    expected_predictions = pd.Series(get_random_state(0).choice(np.unique(y), len(X)), dtype="Int64")
+    expected_predictions = pd.Series(get_random_state(0).choice(np.unique(y), len(X)), dtype="int64")
     predictions = clf.predict(X)
-    assert_series_equal(expected_predictions, predictions.to_series())
+    assert_series_equal(expected_predictions, predictions)
 
     predicted_proba = clf.predict_proba(X)
     assert predicted_proba.shape == (len(X), 2)
     expected_predictions_proba = pd.DataFrame(np.array([[0.5 for i in range(len(values))]] * len(X)))
-    assert_frame_equal(expected_predictions_proba, predicted_proba.to_dataframe())
+    assert_frame_equal(expected_predictions_proba, predicted_proba)
 
     np.testing.assert_allclose(clf.feature_importance, np.array([0.0] * X.shape[1]))
 
@@ -78,14 +78,14 @@ def test_baseline_binary_random_weighted(X_y_binary):
     clf.fit(X, y)
 
     assert clf.classes_ == [0, 1]
-    expected_predictions = pd.Series(get_random_state(0).choice(np.unique(y), len(X), p=percent_freq), dtype="Int64")
+    expected_predictions = pd.Series(get_random_state(0).choice(np.unique(y), len(X), p=percent_freq), dtype="int64")
     predictions = clf.predict(X)
-    assert_series_equal(expected_predictions, predictions.to_series())
+    assert_series_equal(expected_predictions, predictions)
 
     predicted_proba = clf.predict_proba(X)
     assert predicted_proba.shape == (len(X), 2)
     expected_predictions_proba = pd.DataFrame(np.array([[percent_freq[i] for i in range(len(values))]] * len(X)))
-    assert_frame_equal(expected_predictions_proba, predicted_proba.to_dataframe())
+    assert_frame_equal(expected_predictions_proba, predicted_proba)
 
     np.testing.assert_allclose(clf.feature_importance, np.array([0.0] * X.shape[1]))
 
@@ -98,13 +98,13 @@ def test_baseline_multiclass_mode():
 
     assert clf.classes_ == [10, 11, 12]
     predictions = clf.predict(X)
-    expected_predictions = pd.Series([11] * len(X), dtype="Int64")
-    assert_series_equal(expected_predictions, predictions.to_series())
+    expected_predictions = pd.Series([11] * len(X), dtype="int64")
+    assert_series_equal(expected_predictions, predictions)
 
     predicted_proba = clf.predict_proba(X)
     assert predicted_proba.shape == (len(X), 3)
     expected_predictions_proba = pd.DataFrame({10: [0., 0., 0., 0.], 11: [1., 1., 1., 1.], 12: [0., 0., 0., 0.]})
-    assert_frame_equal(expected_predictions_proba, predicted_proba.to_dataframe())
+    assert_frame_equal(expected_predictions_proba, predicted_proba)
 
     np.testing.assert_allclose(clf.feature_importance, np.array([0.0] * X.shape[1]))
 
@@ -116,13 +116,13 @@ def test_baseline_multiclass_random(X_y_multi):
     clf.fit(X, y)
 
     assert clf.classes_ == [0, 1, 2]
-    expected_predictions = pd.Series(get_random_state(0).choice(np.unique(y), len(X)), dtype="Int64")
+    expected_predictions = pd.Series(get_random_state(0).choice(np.unique(y), len(X)), dtype="int64")
     predictions = clf.predict(X)
-    assert_series_equal(expected_predictions, predictions.to_series())
+    assert_series_equal(expected_predictions, predictions)
 
     predicted_proba = clf.predict_proba(X)
     assert predicted_proba.shape == (len(X), 3)
-    assert_frame_equal(pd.DataFrame(np.array([[1. / 3 for i in range(len(values))]] * len(X))), predicted_proba.to_dataframe())
+    assert_frame_equal(pd.DataFrame(np.array([[1. / 3 for i in range(len(values))]] * len(X))), predicted_proba)
     np.testing.assert_allclose(clf.feature_importance, np.array([0.0] * X.shape[1]))
 
 
@@ -135,13 +135,13 @@ def test_baseline_multiclass_random_weighted(X_y_multi):
     clf.fit(X, y)
 
     assert clf.classes_ == [0, 1, 2]
-    expected_predictions = pd.Series(get_random_state(0).choice(np.unique(y), len(X), p=percent_freq), dtype="Int64")
+    expected_predictions = pd.Series(get_random_state(0).choice(np.unique(y), len(X), p=percent_freq), dtype="int64")
     predictions = clf.predict(X)
-    assert_series_equal(expected_predictions, predictions.to_series())
+    assert_series_equal(expected_predictions, predictions)
 
     predicted_proba = clf.predict_proba(X)
     assert predicted_proba.shape == (len(X), 3)
-    assert_frame_equal(pd.DataFrame(np.array([[percent_freq[i] for i in range(len(values))]] * len(X))), predicted_proba.to_dataframe())
+    assert_frame_equal(pd.DataFrame(np.array([[percent_freq[i] for i in range(len(values))]] * len(X))), predicted_proba)
 
     np.testing.assert_allclose(clf.feature_importance, np.array([0.0] * X.shape[1]))
 
@@ -153,12 +153,12 @@ def test_baseline_no_mode():
     clf.fit(X, y)
 
     assert clf.classes_ == [0, 1, 2]
-    expected_predictions = pd.Series([0] * len(X), dtype="Int64")
+    expected_predictions = pd.Series([0] * len(X), dtype="int64")
     predictions = clf.predict(X)
-    assert_series_equal(expected_predictions, predictions.to_series())
+    assert_series_equal(expected_predictions, predictions)
 
     predicted_proba = clf.predict_proba(X)
     assert predicted_proba.shape == (len(X), 3)
-    assert_frame_equal(pd.DataFrame(np.array([[1.0 if i == 0 else 0.0 for i in range(3)]] * len(X))), predicted_proba.to_dataframe())
+    assert_frame_equal(pd.DataFrame(np.array([[1.0 if i == 0 else 0.0 for i in range(3)]] * len(X))), predicted_proba)
 
     np.testing.assert_allclose(clf.feature_importance, np.array([0.0] * X.shape[1]))
