@@ -8,7 +8,6 @@ import cloudpickle
 import numpy as np
 import pandas as pd
 import pytest
-import woodwork as ww
 from skopt.space import Categorical
 
 from evalml.exceptions import (
@@ -190,11 +189,11 @@ def test_describe_component():
     assert us.describe(return_dict=True) == {'name': 'Undersampler', 'parameters': {"sampling_ratio": 0.25, "sampling_ratio_dict": None, "min_samples": 100, "min_percentage": 0.1}}
     try:
         smote = SMOTESampler()
-        assert smote.describe(return_dict=True) == {'name': 'SMOTE Oversampler', 'parameters': {'sampling_ratio': 0.25, 'k_neighbors': 5, 'n_jobs': -1}}
+        assert smote.describe(return_dict=True) == {'name': 'SMOTE Oversampler', 'parameters': {'sampling_ratio': 0.25, "sampling_ratio_dict": None, 'k_neighbors': 5, 'n_jobs': -1}}
         smote = SMOTENCSampler()
-        assert smote.describe(return_dict=True) == {'name': 'SMOTENC Oversampler', 'parameters': {'sampling_ratio': 0.25, 'k_neighbors': 5, 'n_jobs': -1}}
+        assert smote.describe(return_dict=True) == {'name': 'SMOTENC Oversampler', 'parameters': {'sampling_ratio': 0.25, "sampling_ratio_dict": None, 'k_neighbors': 5, 'n_jobs': -1}}
         smote = SMOTENSampler()
-        assert smote.describe(return_dict=True) == {'name': 'SMOTEN Oversampler', 'parameters': {'sampling_ratio': 0.25, 'k_neighbors': 5, 'n_jobs': -1}}
+        assert smote.describe(return_dict=True) == {'name': 'SMOTEN Oversampler', 'parameters': {'sampling_ratio': 0.25, "sampling_ratio_dict": None, 'k_neighbors': 5, 'n_jobs': -1}}
     except ImportError:
         pass
     # testing estimators
@@ -336,7 +335,7 @@ def test_component_fit_transform(X_y_binary):
         hyperparameter_ranges = {}
 
         def fit_transform(self, X, y=None):
-            return ww.DataTable(X)
+            return X
 
         def __init__(self):
             parameters = {}
@@ -365,7 +364,7 @@ def test_component_fit_transform(X_y_binary):
             return self
 
         def transform(self, X, y=None):
-            return ww.DataTable(X)
+            return X
 
         def __init__(self):
             parameters = {}
@@ -392,14 +391,14 @@ def test_component_fit_transform(X_y_binary):
     y = pd.Series(y)
 
     component = MockTransformerWithFitTransform()
-    assert isinstance(component.fit_transform(X, y), ww.DataTable)
+    assert isinstance(component.fit_transform(X, y), pd.DataFrame)
 
     component = MockTransformerWithFitTransformButError()
     with pytest.raises(RuntimeError):
         component.fit_transform(X, y)
 
     component = MockTransformerWithFitAndTransform()
-    assert isinstance(component.fit_transform(X, y), ww.DataTable)
+    assert isinstance(component.fit_transform(X, y), pd.DataFrame)
 
     component = MockTransformerWithOnlyFit()
     with pytest.raises(MethodPropertyNotFoundError):
@@ -556,14 +555,15 @@ def test_transformer_transform_output_type(X_y_binary):
 
             component.fit(X, y=y)
             transform_output = component.transform(X, y=y)
+
             if isinstance(component, TargetImputer):
-                assert isinstance(transform_output[0], ww.DataTable)
-                assert isinstance(transform_output[1], ww.DataColumn)
+                assert isinstance(transform_output[0], pd.DataFrame)
+                assert isinstance(transform_output[1], pd.Series)
             elif 'sampler' in component.name:
-                assert isinstance(transform_output[0], ww.DataTable)
+                assert isinstance(transform_output[0], pd.DataFrame)
                 assert transform_output[1] is None
             else:
-                assert isinstance(transform_output, ww.DataTable)
+                assert isinstance(transform_output, pd.DataFrame)
 
             if isinstance(component, SelectColumns):
                 assert transform_output.shape == (X.shape[0], 0)
@@ -589,10 +589,10 @@ def test_transformer_transform_output_type(X_y_binary):
 
             transform_output = component.fit_transform(X, y=y)
             if isinstance(component, TargetImputer) or 'sampler' in component.name:
-                assert isinstance(transform_output[0], ww.DataTable)
-                assert isinstance(transform_output[1], ww.DataColumn)
+                assert isinstance(transform_output[0], pd.DataFrame)
+                assert isinstance(transform_output[1], pd.Series)
             else:
-                assert isinstance(transform_output, ww.DataTable)
+                assert isinstance(transform_output, pd.DataFrame)
 
             if isinstance(component, SelectColumns):
                 assert transform_output.shape == (X.shape[0], 0)
@@ -636,10 +636,14 @@ def test_estimator_check_for_fit(X_y_binary):
             return self
 
         def predict(self, X):
-            return ww.DataColumn(pd.Series())
+            series = pd.Series()
+            series.ww.init()
+            return series
 
         def predict_proba(self, X):
-            return ww.DataTable(pd.DataFrame())
+            df = pd.DataFrame()
+            df.ww.init()
+            return df
 
     class MockEstimator(Estimator):
         name = "Mock Estimator"
@@ -708,7 +712,9 @@ def test_transformer_check_for_fit_with_overrides(X_y_binary):
             return self
 
         def transform(self, X):
-            return ww.DataTable(pd.DataFrame())
+            df = pd.DataFrame()
+            df.ww.init()
+            return df
 
     class MockTransformerWithOverrideSubclass(Transformer):
         name = "Mock Transformer Subclass"
@@ -717,7 +723,9 @@ def test_transformer_check_for_fit_with_overrides(X_y_binary):
             return self
 
         def transform(self, X):
-            return ww.DataTable(pd.DataFrame())
+            df = pd.DataFrame()
+            df.ww.init()
+            return df
 
     X, y = X_y_binary
     transformer = MockTransformerWithOverride()
@@ -1126,14 +1134,12 @@ def test_transformer_fit_and_transform_respect_custom_indices(use_custom_index,
 
     if 'sampler' in transformer.name:
         X_t, y_t = transformer.transform(X, y)
-        X_t = X_t.to_dataframe()
         assert y_t is None
     elif transformer_class == TargetImputer:
         X_t, y_t = transformer.transform(X, y)
-        X_t = X_t.to_dataframe()
-        pd.testing.assert_index_equal(y_t.to_series().index, y_original_index, check_names=check_names)
+        pd.testing.assert_index_equal(y_t.index, y_original_index, check_names=check_names)
     else:
-        X_t = transformer.transform(X, y).to_dataframe()
+        X_t = transformer.transform(X, y)
         pd.testing.assert_index_equal(y.index, y_original_index, check_names=check_names)
     pd.testing.assert_index_equal(X_t.index, X_original_index, check_names=check_names)
 
