@@ -44,7 +44,7 @@ def test_fit_predict(X_y_regression):
     assert isinstance(fitted, ElasticNetRegressor)
 
     y_pred = clf.predict(X)
-    np.testing.assert_almost_equal(y_pred_sk, y_pred.to_series().values, decimal=5)
+    np.testing.assert_almost_equal(y_pred_sk, y_pred.values, decimal=5)
 
 
 def test_feature_importance(X_y_regression):
