@@ -26,7 +26,7 @@ def imputer_test_data():
         "int with nan": [np.nan, 1, 0, 0, 1],
         "float with nan": [0.0, 1.0, np.nan, -1.0, 0.],
         "object with nan": ["b", "b", np.nan, "c", np.nan],
-        "bool col with nan": pd.Series([True, np.nan, False, np.nan, True], dtype='boolean'),
+        "bool col with nan": pd.Series([True, np.nan, False, np.nan, True], dtype='category'),
         "all nan": [np.nan, np.nan, np.nan, np.nan, np.nan],
         "all nan cat": pd.Series([np.nan, np.nan, np.nan, np.nan, np.nan], dtype='category')
     })
@@ -86,11 +86,11 @@ def test_numeric_only_input(imputer_test_data):
         "int with nan": [0.5, 1.0, 0.0, 0.0, 1.0],
         "float with nan": [0.0, 1.0, 0, -1.0, 0.]
     })
-    assert_frame_equal(transformed.to_dataframe(), expected, check_dtype=False)
+    assert_frame_equal(transformed, expected, check_dtype=False)
 
     imputer = Imputer()
     transformed = imputer.fit_transform(X, y)
-    assert_frame_equal(transformed.to_dataframe(), expected, check_dtype=False)
+    assert_frame_equal(transformed, expected, check_dtype=False)
 
 
 def test_categorical_only_input(imputer_test_data):
@@ -107,12 +107,12 @@ def test_categorical_only_input(imputer_test_data):
         "bool col": [True, False, False, True, True],
         "categorical with nan": pd.Series(["0", "1", "0", "0", "3"], dtype='category'),
         "object with nan": pd.Series(["b", "b", "b", "c", "b"], dtype='category'),
-        "bool col with nan": [True, True, False, True, True]
+        "bool col with nan": pd.Series([True, True, False, True, True], dtype='category')
     })
 
     imputer = Imputer()
     transformed = imputer.fit_transform(X, y)
-    assert_frame_equal(transformed.to_dataframe(), expected, check_dtype=False)
+    assert_frame_equal(transformed, expected, check_dtype=False)
 
 
 def test_categorical_and_numeric_input(imputer_test_data):
@@ -131,27 +131,28 @@ def test_categorical_and_numeric_input(imputer_test_data):
         "int with nan": [0.5, 1.0, 0.0, 0.0, 1.0],
         "float with nan": [0.0, 1.0, 0, -1.0, 0.],
         "object with nan": pd.Series(["b", "b", "b", "c", "b"], dtype='category'),
-        "bool col with nan": [True, True, False, True, True]
+        "bool col with nan": pd.Series([True, True, False, True, True], dtype="category")
     })
-    assert_frame_equal(transformed.to_dataframe(), expected, check_dtype=False)
+    assert_frame_equal(transformed, expected, check_dtype=False)
 
     imputer = Imputer()
     transformed = imputer.fit_transform(X, y)
-    assert_frame_equal(transformed.to_dataframe(), expected, check_dtype=False)
+    assert_frame_equal(transformed, expected, check_dtype=False)
 
 
 def test_drop_all_columns(imputer_test_data):
     X = imputer_test_data[["all nan cat", "all nan"]]
     y = pd.Series([0, 0, 1, 0, 1])
+    X.ww.init()
     imputer = Imputer()
     imputer.fit(X, y)
     transformed = imputer.transform(X, y)
     expected = X.drop(["all nan cat", "all nan"], axis=1)
-    assert_frame_equal(transformed.to_dataframe(), expected, check_dtype=False)
+    assert_frame_equal(transformed, expected, check_dtype=False)
 
     imputer = Imputer()
     transformed = imputer.fit_transform(X, y)
-    assert_frame_equal(transformed.to_dataframe(), expected, check_dtype=False)
+    assert_frame_equal(transformed, expected, check_dtype=False)
 
 
 def test_typed_imputer_numpy_input():
@@ -165,11 +166,11 @@ def test_typed_imputer_numpy_input():
     expected = pd.DataFrame(np.array([[1, 2, 2, 0],
                                       [1, 0, 0, 0],
                                       [1, 1, 1, 0]]))
-    assert_frame_equal(transformed.to_dataframe(), expected, check_dtype=False)
+    assert_frame_equal(transformed, expected, check_dtype=False)
 
     imputer = Imputer()
     transformed = imputer.fit_transform(X, y)
-    assert_frame_equal(transformed.to_dataframe(), expected, check_dtype=False)
+    assert_frame_equal(transformed, expected, check_dtype=False)
 
 
 def test_imputer_datetime_input():
@@ -182,11 +183,11 @@ def test_imputer_datetime_input():
     imputer = Imputer()
     imputer.fit(X, y)
     transformed = imputer.transform(X, y)
-    assert_frame_equal(transformed.to_dataframe(), X, check_dtype=False)
+    assert_frame_equal(transformed, X, check_dtype=False)
 
     imputer = Imputer()
     transformed = imputer.fit_transform(X, y)
-    assert_frame_equal(transformed.to_dataframe(), X, check_dtype=False)
+    assert_frame_equal(transformed, X, check_dtype=False)
 
 
 @pytest.mark.parametrize("data_type", ['np', 'pd', 'ww'])
@@ -199,11 +200,11 @@ def test_imputer_empty_data(data_type, make_data_type):
     imputer = Imputer()
     imputer.fit(X, y)
     transformed = imputer.transform(X, y)
-    assert_frame_equal(transformed.to_dataframe(), expected, check_dtype=False)
+    assert_frame_equal(transformed, expected, check_dtype=False)
 
     imputer = Imputer()
     transformed = imputer.fit_transform(X, y)
-    assert_frame_equal(transformed.to_dataframe(), expected, check_dtype=False)
+    assert_frame_equal(transformed, expected, check_dtype=False)
 
 
 def test_imputer_does_not_reset_index():
@@ -219,7 +220,7 @@ def test_imputer_does_not_reset_index():
     imputer = Imputer()
     imputer.fit(X, y=y)
     transformed = imputer.transform(X)
-    pd.testing.assert_frame_equal(transformed.to_dataframe(),
+    pd.testing.assert_frame_equal(transformed,
                                   pd.DataFrame({'input_val': [1.0, 2, 3, 4, 5, 6, 7, 8, 9],
                                                 'input_cat': pd.Categorical(['a'] * 6 + ['b'] * 3)},
                                                index=list(range(1, 10))))
@@ -240,12 +241,12 @@ def test_imputer_fill_value(imputer_test_data):
         "object with nan": pd.Series(["b", "b", "fill", "c", "fill"], dtype='category'),
         "bool col with nan": pd.Series([True, "fill", False, "fill", True], dtype='category')
     })
-    assert_frame_equal(expected, transformed.to_dataframe(), check_dtype=False)
+    assert_frame_equal(expected, transformed, check_dtype=False)
 
     imputer = Imputer(categorical_impute_strategy="constant", numeric_impute_strategy="constant",
                       categorical_fill_value="fill", numeric_fill_value=-1)
     transformed = imputer.fit_transform(X, y)
-    assert_frame_equal(expected, transformed.to_dataframe(), check_dtype=False)
+    assert_frame_equal(expected, transformed, check_dtype=False)
 
 
 def test_imputer_no_nans(imputer_test_data):
@@ -260,19 +261,19 @@ def test_imputer_no_nans(imputer_test_data):
         "object col": pd.Series(["b", "b", "a", "c", "d"], dtype='category'),
         "bool col": [True, False, False, True, True],
     })
-    assert_frame_equal(transformed.to_dataframe(), expected, check_dtype=False)
+    assert_frame_equal(transformed, expected, check_dtype=False)
 
     imputer = Imputer(categorical_impute_strategy="constant", numeric_impute_strategy="constant",
                       categorical_fill_value="fill", numeric_fill_value=-1)
     transformed = imputer.fit_transform(X, y)
-    assert_frame_equal(transformed.to_dataframe(), expected, check_dtype=False)
+    assert_frame_equal(transformed, expected, check_dtype=False)
 
 
 def test_imputer_with_none():
     X = pd.DataFrame({"int with None": [1, 0, 5, None],
                       "float with None": [0.1, 0.0, 0.5, None],
                       "category with None": pd.Series(["b", "a", "a", None], dtype='category'),
-                      "boolean with None": pd.Series([True, None, False, True], dtype='boolean'),
+                      "boolean with None": pd.Series([True, None, False, True]),
                       "object with None": ["b", "a", "a", None],
                       "all None": [None, None, None, None]})
     y = pd.Series([0, 0, 1, 0, 1])
@@ -282,50 +283,50 @@ def test_imputer_with_none():
     expected = pd.DataFrame({"int with None": [1, 0, 5, 2],
                              "float with None": [0.1, 0.0, 0.5, 0.2],
                              "category with None": pd.Series(["b", "a", "a", "a"], dtype='category'),
-                             "boolean with None": pd.Series([True, True, False, True], dtype='boolean'),
+                             "boolean with None": pd.Series([True, True, False, True], dtype='category'),
                              "object with None": pd.Series(["b", "a", "a", "a"], dtype='category')})
-    assert_frame_equal(expected, transformed.to_dataframe(), check_dtype=False)
+    assert_frame_equal(expected, transformed, check_dtype=False)
 
     imputer = Imputer()
     transformed = imputer.fit_transform(X, y)
-    assert_frame_equal(expected, transformed.to_dataframe(), check_dtype=False)
+    assert_frame_equal(expected, transformed, check_dtype=False)
 
 
 @pytest.mark.parametrize("data_type", ['pd', 'ww'])
 def test_imputer_all_bool_return_original(data_type, make_data_type):
     X = make_data_type(data_type, pd.DataFrame([True, True, False, True, True], dtype=bool))
-    X_expected_arr = pd.DataFrame([True, True, False, True, True], dtype='boolean')
+    X_expected_arr = pd.DataFrame([True, True, False, True, True], dtype=bool)
     y = make_data_type(data_type, pd.Series([1, 0, 0, 1, 0]))
 
     imputer = Imputer()
     imputer.fit(X, y)
     X_t = imputer.transform(X)
-    assert_frame_equal(X_expected_arr, X_t.to_dataframe())
+    assert_frame_equal(X_expected_arr, X_t)
 
 
 @pytest.mark.parametrize("data_type", ['pd', 'ww'])
 def test_imputer_bool_dtype_object(data_type, make_data_type):
-    X = pd.DataFrame([True, np.nan, False, np.nan, True], dtype='boolean')
+    X = pd.DataFrame([True, np.nan, False, np.nan, True])
     y = pd.Series([1, 0, 0, 1, 0])
-    X_expected_arr = pd.DataFrame([True, True, False, True, True], dtype='boolean')
+    X_expected_arr = pd.DataFrame([True, True, False, True, True], dtype='category')
     X = make_data_type(data_type, X)
     y = make_data_type(data_type, y)
     imputer = Imputer()
     imputer.fit(X, y)
     X_t = imputer.transform(X)
-    assert_frame_equal(X_expected_arr, X_t.to_dataframe())
+    assert_frame_equal(X_expected_arr, X_t)
 
 
 @pytest.mark.parametrize("data_type", ['pd', 'ww'])
 def test_imputer_multitype_with_one_bool(data_type, make_data_type):
     X_multi = pd.DataFrame({
-        "bool with nan": pd.Series([True, np.nan, False, np.nan, False], dtype='boolean'),
+        "bool with nan": pd.Series([True, np.nan, False, np.nan, False]),
         "bool no nan": pd.Series([False, False, False, False, True], dtype=bool),
     })
     y = pd.Series([1, 0, 0, 1, 0])
     X_multi_expected_arr = pd.DataFrame({
-        "bool with nan": pd.Series([True, False, False, False, False], dtype='boolean'),
-        "bool no nan": pd.Series([False, False, False, False, True], dtype='boolean'),
+        "bool with nan": pd.Series([True, False, False, False, False], dtype='category'),
+        "bool no nan": pd.Series([False, False, False, False, True], dtype=bool),
     })
 
     X_multi = make_data_type(data_type, X_multi)
@@ -334,34 +335,72 @@ def test_imputer_multitype_with_one_bool(data_type, make_data_type):
     imputer = Imputer()
     imputer.fit(X_multi, y)
     X_multi_t = imputer.transform(X_multi)
-    assert_frame_equal(X_multi_expected_arr, X_multi_t.to_dataframe())
+    assert_frame_equal(X_multi_expected_arr, X_multi_t)
+
+
+def test_imputer_int_preserved():
+    X = pd.DataFrame(pd.Series([1, 2, 11, np.nan]))
+    imputer = Imputer(numeric_impute_strategy="mean")
+    transformed = imputer.fit_transform(X)
+    pd.testing.assert_frame_equal(transformed, pd.DataFrame(pd.Series([1, 2, 11, 14 / 3])))
+    assert transformed.ww.logical_types == {0: Double}
+
+    X = pd.DataFrame(pd.Series([1, 2, 3, np.nan]))
+    imputer = Imputer(numeric_impute_strategy="mean")
+    transformed = imputer.fit_transform(X)
+    pd.testing.assert_frame_equal(transformed, pd.DataFrame(pd.Series([1, 2, 3, 2])), check_dtype=False)
+    assert transformed.ww.logical_types == {0: Double}
+
+    X = pd.DataFrame(pd.Series([1, 2, 3, 4], dtype='int'))
+    imputer = Imputer(numeric_impute_strategy="mean")
+    transformed = imputer.fit_transform(X)
+    pd.testing.assert_frame_equal(transformed, pd.DataFrame(pd.Series([1, 2, 3, 4])), check_dtype=False)
+    assert transformed.ww.logical_types == {0: Integer}
+
+
+def test_imputer_bool_preserved():
+    X = pd.DataFrame(pd.Series([True, False, True, np.nan]))
+    imputer = Imputer(categorical_impute_strategy="most_frequent")
+    transformed = imputer.fit_transform(X)
+    pd.testing.assert_frame_equal(transformed, pd.DataFrame(pd.Series([True, False, True, True], dtype="category")))
+    assert transformed.ww.logical_types == {0: Categorical}
+
+    X = pd.DataFrame(pd.Series([True, False, True, False]))
+    imputer = Imputer(categorical_impute_strategy="most_frequent")
+    transformed = imputer.fit_transform(X)
+    pd.testing.assert_frame_equal(transformed, pd.DataFrame(pd.Series([True, False, True, False])), check_dtype=False)
+    assert transformed.ww.logical_types == {0: Boolean}
 
 
 @pytest.mark.parametrize("X_df", [pd.DataFrame(pd.Series([1, 2, 3], dtype="Int64")),
                                   pd.DataFrame(pd.Series([1., 2., 4.], dtype="float")),
                                   pd.DataFrame(pd.Series(['a', 'b', 'a'], dtype="category")),
-                                  pd.DataFrame(pd.Series([True, False, True], dtype="boolean")),
+                                  pd.DataFrame(pd.Series([True, False, True], dtype=bool)),
                                   pd.DataFrame(pd.Series(['this will be a natural language column because length', 'yay', 'hay'], dtype="string"))])
 @pytest.mark.parametrize("has_nan", [True, False])
 @pytest.mark.parametrize("numeric_impute_strategy", ["mean", "median", "most_frequent"])
 def test_imputer_woodwork_custom_overrides_returned_by_components(X_df, has_nan, numeric_impute_strategy):
     y = pd.Series([1, 2, 1])
-    if has_nan:
-        X_df.iloc[len(X_df) - 1, 0] = np.nan
     override_types = [Integer, Double, Categorical, NaturalLanguage, Boolean]
     for logical_type in override_types:
+        # Column with Nans to boolean used to fail. Now it doesn't but it should.
+        if has_nan and logical_type == Boolean:
+            continue
         try:
-            X = ww.DataTable(X_df, logical_types={0: logical_type})
-        except TypeError:
+            X = X_df.copy()
+            if has_nan:
+                X.iloc[len(X_df) - 1, 0] = np.nan
+            X.ww.init(logical_types={0: logical_type})
+        except ww.exceptions.TypeConversionError:
             continue
 
         imputer = Imputer(numeric_impute_strategy=numeric_impute_strategy)
         imputer.fit(X, y)
         transformed = imputer.transform(X, y)
-        assert isinstance(transformed, ww.DataTable)
+        assert isinstance(transformed, pd.DataFrame)
         if numeric_impute_strategy == "most_frequent":
-            assert transformed.logical_types == {0: logical_type}
+            assert transformed.ww.logical_types == {0: logical_type}
         elif logical_type in [Categorical, NaturalLanguage] or not has_nan:
-            assert transformed.logical_types == {0: logical_type}
+            assert transformed.ww.logical_types == {0: logical_type}
         else:
-            assert transformed.logical_types == {0: Double}
+            assert transformed.ww.logical_types == {0: Double}
