@@ -50,8 +50,8 @@ def test_fit_predict_binary(X_y_binary):
     y_pred = clf.predict(X)
     y_pred_proba = clf.predict_proba(X)
 
-    np.testing.assert_almost_equal(y_pred_sk, y_pred.to_series().values, decimal=5)
-    np.testing.assert_almost_equal(y_pred_proba_sk, y_pred_proba.to_dataframe().values, decimal=5)
+    np.testing.assert_almost_equal(y_pred_sk, y_pred.values, decimal=5)
+    np.testing.assert_almost_equal(y_pred_proba_sk, y_pred_proba.values, decimal=5)
 
 
 def test_fit_predict_multi(X_y_multi):
@@ -67,8 +67,8 @@ def test_fit_predict_multi(X_y_multi):
     y_pred = clf.predict(X)
     y_pred_proba = clf.predict_proba(X)
 
-    np.testing.assert_almost_equal(y_pred_sk, y_pred.to_series().values, decimal=5)
-    np.testing.assert_almost_equal(y_pred_proba_sk, y_pred_proba.to_dataframe().values, decimal=5)
+    np.testing.assert_almost_equal(y_pred_sk, y_pred.values, decimal=5)
+    np.testing.assert_almost_equal(y_pred_proba_sk, y_pred_proba.values, decimal=5)
 
 
 def test_feature_importance(X_y_binary):
@@ -104,8 +104,8 @@ def test_fit_string_features(X_y_binary):
     y_pred = clf.predict(X)
     y_pred_proba = clf.predict_proba(X)
 
-    np.testing.assert_almost_equal(y_pred_sk, y_pred.to_series().values, decimal=5)
-    np.testing.assert_almost_equal(y_pred_proba_sk, y_pred_proba.to_dataframe().values, decimal=5)
+    np.testing.assert_almost_equal(y_pred_sk, y_pred.values, decimal=5)
+    np.testing.assert_almost_equal(y_pred_proba_sk, y_pred_proba.values, decimal=5)
 
 
 @patch('evalml.pipelines.components.estimators.estimator.Estimator.predict_proba')
@@ -274,5 +274,5 @@ def test_lightgbm_multiindex(data_type, X_y_binary, make_data_type):
     clf.fit(X, y)
     y_pred = clf.predict(X)
     y_pred_proba = clf.predict_proba(X)
-    assert not y_pred.to_series().isnull().values.any()
-    assert not y_pred_proba.to_dataframe().isnull().values.any().any()
+    assert not y_pred.isnull().values.any()
+    assert not y_pred_proba.isnull().values.any().any()
