@@ -27,7 +27,7 @@ def test_simple_imputer_median():
                                    [10, 2, 5, 2],
                                    [6, 2, 7, 0]])
     X_t = transformer.fit_transform(X)
-    assert_frame_equal(X_expected_arr, X_t.to_dataframe(), check_dtype=False)
+    assert_frame_equal(X_expected_arr, X_t, check_dtype=False)
 
 
 def test_simple_imputer_mean():
@@ -40,7 +40,7 @@ def test_simple_imputer_mean():
                                    [1, 2, 3, 2],
                                    [1, 2, 3, 0]])
     X_t = transformer.fit_transform(X)
-    assert_frame_equal(X_expected_arr, X_t.to_dataframe(), check_dtype=False)
+    assert_frame_equal(X_expected_arr, X_t, check_dtype=False)
 
 
 def test_simple_imputer_constant():
@@ -55,7 +55,7 @@ def test_simple_imputer_constant():
                                    ["b", 2, 3, 0]])
     X_expected_arr = X_expected_arr.astype({0: 'category'})
     X_t = transformer.fit_transform(X)
-    assert_frame_equal(X_expected_arr, X_t.to_dataframe(), check_dtype=False)
+    assert_frame_equal(X_expected_arr, X_t, check_dtype=False)
 
 
 def test_simple_imputer_most_frequent():
@@ -69,7 +69,7 @@ def test_simple_imputer_most_frequent():
                                    ["b", 2, 1, 0]])
     X_expected_arr = X_expected_arr.astype({0: 'category'})
     X_t = transformer.fit_transform(X)
-    assert_frame_equal(X_expected_arr, X_t.to_dataframe(), check_dtype=False)
+    assert_frame_equal(X_expected_arr, X_t, check_dtype=False)
 
 
 def test_simple_imputer_col_with_non_numeric():
@@ -98,7 +98,7 @@ def test_simple_imputer_col_with_non_numeric():
                                    ["a", 2, 3, 0]])
     X_expected_arr = X_expected_arr.astype({0: 'category'})
     X_t = transformer.fit_transform(X)
-    assert_frame_equal(X_expected_arr, X_t.to_dataframe(), check_dtype=False)
+    assert_frame_equal(X_expected_arr, X_t, check_dtype=False)
 
     transformer = SimpleImputer(impute_strategy='constant', fill_value=2)
     X_expected_arr = pd.DataFrame([["a", 0, 1, 2],
@@ -107,7 +107,7 @@ def test_simple_imputer_col_with_non_numeric():
                                    [2, 2, 3, 0]])
     X_expected_arr = X_expected_arr.astype({0: 'category'})
     X_t = transformer.fit_transform(X)
-    assert_frame_equal(X_expected_arr, X_t.to_dataframe(), check_dtype=False)
+    assert_frame_equal(X_expected_arr, X_t, check_dtype=False)
 
 
 @pytest.mark.parametrize("data_type", ['pd', 'ww'])
@@ -116,42 +116,42 @@ def test_simple_imputer_all_bool_return_original(data_type, make_data_type):
     y = pd.Series([1, 0, 0, 1, 0])
     X = make_data_type(data_type, X)
     y = make_data_type(data_type, y)
-    X_expected_arr = pd.DataFrame([True, True, False, True, True], dtype='boolean')
+    X_expected_arr = pd.DataFrame([True, True, False, True, True], dtype=bool)
     imputer = SimpleImputer()
     imputer.fit(X, y)
     X_t = imputer.transform(X)
-    assert_frame_equal(X_expected_arr, X_t.to_dataframe())
+    assert_frame_equal(X_expected_arr, X_t)
 
 
 @pytest.mark.parametrize("data_type", ['pd', 'ww'])
 def test_simple_imputer_boolean_dtype(data_type, make_data_type):
-    X = pd.DataFrame([True, np.nan, False, np.nan, True], dtype='boolean')
+    X = pd.DataFrame([True, np.nan, False, np.nan, True])
     y = pd.Series([1, 0, 0, 1, 0])
-    X_expected_arr = pd.DataFrame([True, True, False, True, True], dtype='boolean')
+    X_expected_arr = pd.DataFrame([True, True, False, True, True], dtype='category')
     X = make_data_type(data_type, X)
     imputer = SimpleImputer()
     imputer.fit(X, y)
     X_t = imputer.transform(X)
-    assert_frame_equal(X_expected_arr, X_t.to_dataframe())
+    assert_frame_equal(X_expected_arr, X_t)
 
 
 @pytest.mark.parametrize("data_type", ['pd', 'ww'])
 def test_simple_imputer_multitype_with_one_bool(data_type, make_data_type):
     X_multi = pd.DataFrame({
-        "bool with nan": pd.Series([True, np.nan, False, np.nan, False], dtype='boolean'),
+        "bool with nan": pd.Series([True, np.nan, False, np.nan, False]),
         "bool no nan": pd.Series([False, False, False, False, True], dtype=bool),
     })
     y = pd.Series([1, 0, 0, 1, 0])
     X_multi_expected_arr = pd.DataFrame({
-        "bool with nan": pd.Series([True, False, False, False, False], dtype='boolean'),
-        "bool no nan": pd.Series([False, False, False, False, True], dtype='boolean'),
+        "bool with nan": pd.Series([True, False, False, False, False], dtype='category'),
+        "bool no nan": pd.Series([False, False, False, False, True], dtype=bool),
     })
     X_multi = make_data_type(data_type, X_multi)
 
     imputer = SimpleImputer()
     imputer.fit(X_multi, y)
     X_multi_t = imputer.transform(X_multi)
-    assert_frame_equal(X_multi_expected_arr, X_multi_t.to_dataframe())
+    assert_frame_equal(X_multi_expected_arr, X_multi_t)
 
 
 def test_simple_imputer_fit_transform_drop_all_nan_columns():
@@ -162,7 +162,7 @@ def test_simple_imputer_fit_transform_drop_all_nan_columns():
     transformer = SimpleImputer(impute_strategy='most_frequent')
     X_expected_arr = pd.DataFrame({"some_nan": [0, 1, 0], "another_col": [0, 1, 2]})
     X_t = transformer.fit_transform(X)
-    assert_frame_equal(X_expected_arr, X_t.to_dataframe(), check_dtype=False)
+    assert_frame_equal(X_expected_arr, X_t, check_dtype=False)
     assert_frame_equal(X, pd.DataFrame({"all_nan": [np.nan, np.nan, np.nan],
                                         "some_nan": [np.nan, 1, 0],
                                         "another_col": [0, 1, 2]}))
@@ -175,7 +175,7 @@ def test_simple_imputer_transform_drop_all_nan_columns():
     transformer = SimpleImputer(impute_strategy='most_frequent')
     transformer.fit(X)
     X_expected_arr = pd.DataFrame({"some_nan": [0, 1, 0], "another_col": [0, 1, 2]})
-    assert_frame_equal(X_expected_arr, transformer.transform(X).to_dataframe(), check_dtype=False)
+    assert_frame_equal(X_expected_arr, transformer.transform(X), check_dtype=False)
     assert_frame_equal(X, pd.DataFrame({"all_nan": [np.nan, np.nan, np.nan],
                                         "some_nan": [np.nan, 1, 0],
                                         "another_col": [0, 1, 2]}))
@@ -184,12 +184,12 @@ def test_simple_imputer_transform_drop_all_nan_columns():
 def test_simple_imputer_transform_drop_all_nan_columns_empty():
     X = pd.DataFrame([[np.nan, np.nan, np.nan]])
     transformer = SimpleImputer(impute_strategy='most_frequent')
-    assert transformer.fit_transform(X).to_dataframe().empty
+    assert transformer.fit_transform(X).empty
     assert_frame_equal(X, pd.DataFrame([[np.nan, np.nan, np.nan]]))
 
     transformer = SimpleImputer(impute_strategy='most_frequent')
     transformer.fit(X)
-    assert transformer.transform(X).to_dataframe().empty
+    assert transformer.transform(X).empty
     assert_frame_equal(X, pd.DataFrame([[np.nan, np.nan, np.nan]]))
 
 
@@ -201,7 +201,7 @@ def test_simple_imputer_numpy_input():
     X_expected_arr = np.array([[0, 1, 1],
                                [2, 3, 2],
                                [2, 3, 0]])
-    assert np.allclose(X_expected_arr, transformer.fit_transform(X).to_dataframe())
+    assert np.allclose(X_expected_arr, transformer.fit_transform(X))
     np.testing.assert_almost_equal(X, np.array([[np.nan, 0, 1, np.nan],
                                                 [np.nan, 2, 3, 2],
                                                 [np.nan, 2, 3, 0]]))
@@ -233,11 +233,11 @@ def test_simple_imputer_fill_value(data_type):
     imputer = SimpleImputer(impute_strategy="constant", fill_value=fill_value)
     imputer.fit(X, y)
     transformed = imputer.transform(X, y)
-    assert_frame_equal(expected, transformed.to_dataframe(), check_dtype=False)
+    assert_frame_equal(expected, transformed, check_dtype=False)
 
     imputer = SimpleImputer(impute_strategy="constant", fill_value=fill_value)
     transformed = imputer.fit_transform(X, y)
-    assert_frame_equal(expected, transformed.to_dataframe(), check_dtype=False)
+    assert_frame_equal(expected, transformed, check_dtype=False)
 
 
 def test_simple_imputer_does_not_reset_index():
@@ -256,7 +256,7 @@ def test_simple_imputer_does_not_reset_index():
     pd.testing.assert_frame_equal(pd.DataFrame({'input_val': [1, 2, 3, 4, 5, 6, 7, 8, 9]},
                                                dtype=float,
                                                index=list(range(1, 10))),
-                                  transformed.to_dataframe())
+                                  transformed)
 
 
 def test_simple_imputer_with_none():
@@ -269,10 +269,10 @@ def test_simple_imputer_with_none():
     transformed = imputer.transform(X, y)
     expected = pd.DataFrame({"int with None": [1, 0, 5, 2],
                              "float with None": [0.1, 0.0, 0.5, 0.2]})
-    assert_frame_equal(expected, transformed.to_dataframe(), check_dtype=False)
+    assert_frame_equal(expected, transformed, check_dtype=False)
 
     X = pd.DataFrame({"category with None": pd.Series(["b", "a", "a", None], dtype='category'),
-                      "boolean with None": pd.Series([True, None, False, True], dtype='boolean'),
+                      "boolean with None": pd.Series([True, None, False, True]),
                       "object with None": ["b", "a", "a", None],
                       "all None": [None, None, None, None]})
     y = pd.Series([0, 0, 1, 0, 1])
@@ -280,27 +280,44 @@ def test_simple_imputer_with_none():
     imputer.fit(X, y)
     transformed = imputer.transform(X, y)
     expected = pd.DataFrame({"category with None": pd.Series(["b", "a", "a", "a"], dtype='category'),
-                             "boolean with None": pd.Series([True, True, False, True], dtype='boolean'),
+                             "boolean with None": pd.Series([True, True, False, True], dtype='category'),
                              "object with None": pd.Series(["b", "a", "a", "a"], dtype='category')})
-    assert_frame_equal(expected, transformed.to_dataframe(), check_dtype=False)
+    assert_frame_equal(expected, transformed, check_dtype=False)
+
+
+def test_simple_imputer_supports_natural_language_constant():
+    X = pd.DataFrame({"cat with None": ["a", "b", "a", None],
+                      "natural language col": ["free-form text", "will", "be imputed", None]})
+    y = pd.Series([0, 0, 1, 0, 1])
+    X.ww.init(logical_types={"natural language col": "NaturalLanguage"})
+    imputer = SimpleImputer(impute_strategy="constant", fill_value="placeholder")
+    imputer.fit(X, y)
+    transformed = imputer.transform(X, y)
+    expected = pd.DataFrame({"cat with None": pd.Series(["a", "b", "a", "placeholder"], dtype='category'),
+                             "natural language col": pd.Series(["free-form text", "will", "be imputed", "placeholder"], dtype='string')})
+    assert_frame_equal(expected, transformed, check_dtype=False)
 
 
 @pytest.mark.parametrize("X_df", [pd.DataFrame(pd.Series([1, 2, 3], dtype="Int64")),
                                   pd.DataFrame(pd.Series([1., 2., 3.], dtype="float")),
                                   pd.DataFrame(pd.Series(['a', 'b', 'a'], dtype="category")),
-                                  pd.DataFrame(pd.Series([True, False, True], dtype="boolean")),
+                                  pd.DataFrame(pd.Series([True, False, True], dtype=bool)),
                                   pd.DataFrame(pd.Series(['this will be a natural language column because length', 'yay', 'hay'], dtype="string"))])
 @pytest.mark.parametrize("has_nan", [True, False])
-@pytest.mark.parametrize("impute_strategy", ["mean", "median", "most_frequent"])
+@pytest.mark.parametrize("impute_strategy", ["mean", "median"])
 def test_simple_imputer_woodwork_custom_overrides_returned_by_components(X_df, has_nan, impute_strategy):
     y = pd.Series([1, 2, 1])
-    if has_nan:
-        X_df.iloc[len(X_df) - 1, 0] = np.nan
     override_types = [Integer, Double, Categorical, NaturalLanguage, Boolean]
     for logical_type in override_types:
+        # Column with Nans to boolean used to fail. Now it doesn't
+        if has_nan and logical_type == Boolean:
+            continue
         try:
-            X = ww.DataTable(X_df, logical_types={0: logical_type})
-        except TypeError:
+            X = X_df.copy()
+            if has_nan:
+                X.iloc[len(X_df) - 1, 0] = np.nan
+            X.ww.init(logical_types={0: logical_type})
+        except ww.exceptions.TypeConversionError:
             continue
 
         impute_strategy_to_use = impute_strategy
@@ -310,8 +327,8 @@ def test_simple_imputer_woodwork_custom_overrides_returned_by_components(X_df, h
         imputer = SimpleImputer(impute_strategy=impute_strategy_to_use)
         imputer.fit(X, y)
         transformed = imputer.transform(X, y)
-        assert isinstance(transformed, ww.DataTable)
+        assert isinstance(transformed, pd.DataFrame)
         if impute_strategy_to_use == "most_frequent" or not has_nan:
-            assert transformed.logical_types == {0: logical_type}
+            assert transformed.ww.logical_types == {0: logical_type}
         else:
-            assert transformed.logical_types == {0: Double}
+            assert transformed.ww.logical_types == {0: Double}
