@@ -66,7 +66,7 @@ def test_null_values_in_dataframe():
                                'col_2': [0.526894, 0.526894, 0.526894, 0.6, 0.526894],
                                'col_3': [0.6, 0.6, 0.6, 0.6, 0.6, ]})
 
-    assert_frame_equal(X_expected, X_t.to_dataframe())
+    assert_frame_equal(X_expected, X_t)
 
     encoder = TargetEncoder(handle_missing='return_nan')
     encoder.fit(X, y)
@@ -74,7 +74,7 @@ def test_null_values_in_dataframe():
     X_expected = pd.DataFrame({'col_1': [0.6, 0.6, 0.6, 0.6, np.nan],
                                'col_2': [0.526894, 0.526894, 0.526894, 0.6, 0.526894],
                                'col_3': [0.6, 0.6, 0.6, 0.6, 0.6, ]})
-    assert_frame_equal(X_expected, X_t.to_dataframe())
+    assert_frame_equal(X_expected, X_t)
 
     encoder = TargetEncoder(handle_missing='error')
     with pytest.raises(ValueError, match='Columns to be encoded can not contain null'):
@@ -85,20 +85,20 @@ def test_cols():
     X = pd.DataFrame({'col_1': [1, 2, 1, 1, 2],
                       'col_2': ['2', '1', '1', '1', '1'],
                       'col_3': ["a", "a", "a", "a", "a"]})
-    X_expected = X.astype({'col_1': 'Int64', 'col_2': 'category', 'col_3': 'category'})
+    X_expected = X.astype({'col_1': 'int64', 'col_2': 'category', 'col_3': 'category'})
     y = pd.Series([0, 1, 1, 1, 0])
     encoder = TargetEncoder(cols=[])
     encoder.fit(X, y)
     X_t = encoder.transform(X)
-    assert_frame_equal(X_expected, X_t.to_dataframe())
+    assert_frame_equal(X_expected, X_t)
 
     encoder = TargetEncoder(cols=['col_2'])
     encoder.fit(X, y)
     X_t = encoder.transform(X)
-    X_expected = pd.DataFrame({'col_1': pd.Series([1, 2, 1, 1, 2], dtype="Int64"),
+    X_expected = pd.DataFrame({'col_1': pd.Series([1, 2, 1, 1, 2], dtype="int64"),
                                'col_2': [0.60000, 0.742886, 0.742886, 0.742886, 0.742886],
                                'col_3': pd.Series(["a", "a", "a", "a", "a"], dtype="category")})
-    assert_frame_equal(X_expected, X_t.to_dataframe(), check_less_precise=True)
+    assert_frame_equal(X_expected, X_t, check_less_precise=True)
 
     encoder = TargetEncoder(cols=['col_2', 'col_3'])
     encoder.fit(X, y)
@@ -106,7 +106,7 @@ def test_cols():
     encoder2 = TargetEncoder()
     encoder2.fit(X, y)
     X_t2 = encoder2.transform(X)
-    assert_frame_equal(X_t.to_dataframe(), X_t2.to_dataframe())
+    assert_frame_equal(X_t, X_t2)
 
 
 def test_transform():
@@ -117,10 +117,10 @@ def test_transform():
     encoder = TargetEncoder()
     encoder.fit(X, y)
     X_t = encoder.transform(X)
-    X_expected = pd.DataFrame({'col_1': pd.Series([1, 2, 1, 1, 2], dtype="Int64"),
+    X_expected = pd.DataFrame({'col_1': pd.Series([1, 2, 1, 1, 2], dtype="int64"),
                                'col_2': [0.6, 0.65872, 0.6, 0.65872, 0.65872],
                                'col_3': [0.504743, 0.504743, 0.504743, 0.6, 0.504743]})
-    assert_frame_equal(X_expected, X_t.to_dataframe())
+    assert_frame_equal(X_expected, X_t)
 
 
 def test_smoothing():
@@ -132,26 +132,26 @@ def test_smoothing():
     encoder = TargetEncoder(smoothing=1)
     encoder.fit(X, y)
     X_t = encoder.transform(X)
-    X_expected = pd.DataFrame({'col_1': pd.Series([1, 2, 1, 1, 2], dtype="Int64"),
-                               'col_2': pd.Series([2, 1, 1, 1, 1], dtype="Int64"),
+    X_expected = pd.DataFrame({'col_1': pd.Series([1, 2, 1, 1, 2], dtype="int64"),
+                               'col_2': pd.Series([2, 1, 1, 1, 1], dtype="int64"),
                                'col_3': [0.742886, 0.742886, 0.742886, 0.742886, 0.6]})
-    assert_frame_equal(X_expected, X_t.to_dataframe())
+    assert_frame_equal(X_expected, X_t)
 
     encoder = TargetEncoder(smoothing=10)
     encoder.fit(X, y)
     X_t = encoder.transform(X)
-    X_expected = pd.DataFrame({'col_1': pd.Series([1, 2, 1, 1, 2], dtype="Int64"),
-                               'col_2': pd.Series([2, 1, 1, 1, 1], dtype="Int64"),
+    X_expected = pd.DataFrame({'col_1': pd.Series([1, 2, 1, 1, 2], dtype="int64"),
+                               'col_2': pd.Series([2, 1, 1, 1, 1], dtype="int64"),
                                'col_3': [0.686166, 0.686166, 0.686166, 0.686166, 0.6]})
-    assert_frame_equal(X_expected, X_t.to_dataframe())
+    assert_frame_equal(X_expected, X_t)
 
     encoder = TargetEncoder(smoothing=100)
     encoder.fit(X, y)
     X_t = encoder.transform(X)
-    X_expected = pd.DataFrame({'col_1': pd.Series([1, 2, 1, 1, 2], dtype="Int64"),
-                               'col_2': pd.Series([2, 1, 1, 1, 1], dtype="Int64"),
+    X_expected = pd.DataFrame({'col_1': pd.Series([1, 2, 1, 1, 2], dtype="int64"),
+                               'col_2': pd.Series([2, 1, 1, 1, 1], dtype="int64"),
                                'col_3': [0.676125, 0.676125, 0.676125, 0.676125, 0.6]})
-    assert_frame_equal(X_expected, X_t.to_dataframe())
+    assert_frame_equal(X_expected, X_t)
 
 
 def test_get_feature_names():
@@ -191,16 +191,17 @@ def test_target_encoder_woodwork_custom_overrides_returned_by_components(X_df):
     override_types = [Integer, Double, Categorical, NaturalLanguage, Boolean, Datetime]
     for logical_type in override_types:
         try:
-            X = ww.DataTable(X_df, logical_types={0: logical_type})
-        except TypeError:
+            X = X_df.copy()
+            X.ww.init(logical_types={0: logical_type})
+        except ww.exceptions.TypeConversionError:
             continue
 
         encoder = TargetEncoder()
         encoder.fit(X, y)
         transformed = encoder.transform(X, y)
-        assert isinstance(transformed, ww.DataTable)
+        assert isinstance(transformed, pd.DataFrame)
 
         if logical_type == Categorical:
-            assert transformed.logical_types == {0: Double}
+            assert transformed.ww.logical_types == {0: Double}
         else:
-            assert transformed.logical_types == {0: logical_type}
+            assert transformed.ww.logical_types == {0: logical_type}
