@@ -31,8 +31,8 @@ def test_target_imputer_with_X():
     y_expected = pd.Series([2, 1, 3])
     X_expected = pd.DataFrame({"some col": [1, 3, np.nan]})
     X_t, y_t = imputer.fit_transform(X, y)
-    assert_series_equal(y_expected, y_t.to_series(), check_dtype=False)
-    assert_frame_equal(X_expected, X_t.to_dataframe(), check_dtype=False)
+    assert_series_equal(y_expected, y_t, check_dtype=False)
+    assert_frame_equal(X_expected, X_t, check_dtype=False)
 
 
 def test_target_imputer_median():
@@ -40,7 +40,7 @@ def test_target_imputer_median():
     imputer = TargetImputer(impute_strategy='median')
     y_expected = pd.Series([8, 1, 10, 10, 6])
     _, y_t = imputer.fit_transform(None, y)
-    assert_series_equal(y_expected, y_t.to_series(), check_dtype=False)
+    assert_series_equal(y_expected, y_t, check_dtype=False)
 
 
 def test_target_imputer_mean():
@@ -48,7 +48,7 @@ def test_target_imputer_mean():
     imputer = TargetImputer(impute_strategy='mean')
     y_expected = pd.Series([1, 2, 0])
     _, y_t = imputer.fit_transform(None, y)
-    assert_series_equal(y_expected, y_t.to_series(), check_dtype=False)
+    assert_series_equal(y_expected, y_t, check_dtype=False)
 
 
 @pytest.mark.parametrize("fill_value, y, y_expected", [(None, pd.Series([np.nan, 0, 5]), pd.Series([0, 0, 5])),
@@ -58,7 +58,7 @@ def test_target_imputer_mean():
 def test_target_imputer_constant(fill_value, y, y_expected):
     imputer = TargetImputer(impute_strategy='constant', fill_value=fill_value)
     _, y_t = imputer.fit_transform(None, y)
-    assert_series_equal(y_expected, y_t.to_series(), check_dtype=False)
+    assert_series_equal(y_expected, y_t, check_dtype=False)
 
 
 def test_target_imputer_most_frequent():
@@ -66,13 +66,13 @@ def test_target_imputer_most_frequent():
     imputer = TargetImputer(impute_strategy='most_frequent')
     y_expected = pd.Series(["a", "a", "b"]).astype("category")
     _, y_t = imputer.fit_transform(None, y)
-    assert_series_equal(y_expected, y_t.to_series(), check_dtype=False)
+    assert_series_equal(y_expected, y_t, check_dtype=False)
 
     y = pd.Series([np.nan, 1, 1, 2])
     imputer = TargetImputer(impute_strategy='most_frequent')
     y_expected = pd.Series([1, 1, 1, 2])
     _, y_t = imputer.fit_transform(None, y)
-    assert_series_equal(y_expected, y_t.to_series(), check_dtype=False)
+    assert_series_equal(y_expected, y_t, check_dtype=False)
 
 
 def test_target_imputer_col_with_non_numeric_with_numeric_strategy():
@@ -93,22 +93,22 @@ def test_target_imputer_col_with_non_numeric_with_numeric_strategy():
 def test_target_imputer_all_bool_return_original(data_type, make_data_type):
     y = pd.Series([True, True, False, True, True], dtype=bool)
     y = make_data_type(data_type, y)
-    y_expected = pd.Series([True, True, False, True, True], dtype='boolean')
+    y_expected = pd.Series([True, True, False, True, True], dtype=bool)
     imputer = TargetImputer()
     imputer.fit(None, y)
     _, y_t = imputer.transform(None, y)
-    assert_series_equal(y_expected, y_t.to_series())
+    assert_series_equal(y_expected, y_t)
 
 
 @pytest.mark.parametrize("data_type", ['pd', 'ww'])
 def test_target_imputer_boolean_dtype(data_type, make_data_type):
-    y = pd.Series([True, np.nan, False, np.nan, True], dtype='boolean')
-    y_expected = pd.Series([True, True, False, True, True], dtype='boolean')
+    y = pd.Series([True, np.nan, False, np.nan, True], dtype='category')
+    y_expected = pd.Series([True, True, False, True, True], dtype='category')
     y = make_data_type(data_type, y)
     imputer = TargetImputer()
     imputer.fit(None, y)
     _, y_t = imputer.transform(None, y)
-    assert_series_equal(y_expected, y_t.to_series())
+    assert_series_equal(y_expected, y_t)
 
 
 def test_target_imputer_fit_transform_all_nan_empty():
@@ -129,7 +129,7 @@ def test_target_imputer_numpy_input():
     imputer = TargetImputer(impute_strategy='mean')
     y_expected = np.array([1, 0, 2])
     _, y_t = imputer.fit_transform(None, y)
-    assert np.allclose(y_expected, y_t.to_series())
+    assert np.allclose(y_expected, y_t)
     np.testing.assert_almost_equal(y, np.array([np.nan, 0, 2]))
 
 
@@ -144,7 +144,7 @@ def test_target_imputer_does_not_reset_index():
     imputer = TargetImputer(impute_strategy="mean")
     imputer.fit(None, y=y)
     _, y_t = imputer.transform(None, y)
-    pd.testing.assert_series_equal(pd.Series([1.0, 2, 3, 4, 5, 6, 7, 8, 9], dtype=float, index=list(range(1, 10))), y_t.to_series())
+    pd.testing.assert_series_equal(pd.Series([1.0, 2, 3, 4, 5, 6, 7, 8, 9], dtype=float, index=list(range(1, 10))), y_t)
 
 
 @pytest.mark.parametrize("y, y_expected", [(pd.Series([1, 0, 5, None]), pd.Series([1, 0, 5, 2])),
@@ -152,23 +152,22 @@ def test_target_imputer_does_not_reset_index():
 def test_target_imputer_with_none(y, y_expected):
     imputer = TargetImputer(impute_strategy="mean")
     _, y_t = imputer.fit_transform(None, y)
-    assert_series_equal(y_expected, y_t.to_series(), check_dtype=False)
+    assert_series_equal(y_expected, y_t, check_dtype=False)
 
 
 @pytest.mark.parametrize("y, y_expected", [(pd.Series(["b", "a", "a", None], dtype='category'), pd.Series(["b", "a", "a", "a"], dtype='category')),
-                                           (pd.Series([True, None, False, True], dtype='boolean'), pd.Series([True, True, False, True], dtype='boolean')),
+                                           (pd.Series([True, None, False, True], dtype='category'), pd.Series([True, True, False, True], dtype='category')),
                                            (pd.Series(["b", "a", "a", None]), pd.Series(["b", "a", "a", "a"], dtype='category'))])
 def test_target_imputer_with_none_non_numeric(y, y_expected):
     imputer = TargetImputer()
     _, y_t = imputer.fit_transform(None, y)
-    assert_series_equal(y_expected, y_t.to_series(), check_dtype=False)
+    assert_series_equal(y_expected, y_t, check_dtype=False)
 
 
 @pytest.mark.parametrize("y_pd", [pd.Series([1, 2, 3], dtype="int64"),
                                   pd.Series([1., 2., 3.], dtype="float"),
                                   pd.Series(['a', 'b', 'a'], dtype="category"),
-                                  pd.Series([True, False, True], dtype="boolean"),
-                                  pd.Series(['this will be a natural language column because length', 'yay', 'hay'], dtype="string")])
+                                  pd.Series([True, False, True], dtype=bool)])
 @pytest.mark.parametrize("has_nan", [True, False])
 @pytest.mark.parametrize("impute_strategy", ["mean", "median", "most_frequent"])
 def test_target_imputer_woodwork_custom_overrides_returned_by_components(y_pd, has_nan, impute_strategy):
@@ -177,9 +176,12 @@ def test_target_imputer_woodwork_custom_overrides_returned_by_components(y_pd, h
         y_to_use[len(y_pd) - 1] = np.nan
     override_types = [Integer, Double, Categorical, Boolean]
     for logical_type in override_types:
+        # Converting a column with NaNs to Boolean will impute NaNs.
+        if has_nan and logical_type == Boolean:
+            continue
         try:
-            y = ww.DataColumn(y_to_use.copy(), logical_type=logical_type)
-        except TypeError:
+            y = ww.init_series(y_to_use.copy(), logical_type=logical_type)
+        except (ww.exceptions.TypeConversionError, ValueError):
             continue
 
         impute_strategy_to_use = impute_strategy
@@ -189,9 +191,8 @@ def test_target_imputer_woodwork_custom_overrides_returned_by_components(y_pd, h
         imputer = TargetImputer(impute_strategy=impute_strategy_to_use)
         imputer.fit(None, y)
         _, y_t = imputer.transform(None, y)
-        assert isinstance(y_t, ww.DataColumn)
 
         if impute_strategy_to_use == "most_frequent" or not has_nan:
-            assert y_t.logical_type == logical_type
+            assert y_t.ww.logical_type == logical_type
         else:
-            assert y_t.logical_type == Double
+            assert y_t.ww.logical_type == Double
