@@ -33,7 +33,7 @@ def test_xgboost_feature_name_with_random_ascii(X_y_regression):
     clf.fit(X, y)
     predictions = clf.predict(X)
     assert len(predictions) == len(y)
-    assert not np.isnan(predictions.to_series()).all()
+    assert not np.isnan(predictions).all()
 
     assert len(clf.feature_importance) == len(X.columns)
     assert not np.isnan(clf.feature_importance).all().all()
@@ -51,4 +51,4 @@ def test_xgboost_multiindex(data_type, X_y_regression, make_data_type):
     clf = XGBoostRegressor()
     clf.fit(X, y)
     y_pred = clf.predict(X)
-    assert not y_pred.to_series().isnull().values.any()
+    assert not y_pred.isnull().values.any()
