@@ -1,7 +1,6 @@
 import numpy as np
 import pandas as pd
 import pytest
-import woodwork as ww
 
 from evalml.data_checks import (
     DataCheckAction,
@@ -141,7 +140,8 @@ def test_id_cols_data_check_input_formats():
     assert id_cols_check.validate(pd.DataFrame()) == {"warnings": [], "errors": [], "actions": []}
 
     #  test Woodwork
-    ww_input = ww.DataTable(np.array([[0, 1], [1, 2], [2, 3], [3, 4], [4, 5]]))
+    ww_input = pd.DataFrame(np.array([[0, 1], [1, 2], [2, 3], [3, 4], [4, 5]]))
+    ww_input.ww.init()
     assert id_cols_check.validate(ww_input) == {
         "warnings": [DataCheckWarning(message="Column '0' is 80.0% or more likely to be an ID column",
                                       data_check_name=id_data_check_name,
