@@ -117,8 +117,11 @@ def test_target_leakage_data_check_input_formats():
                     DataCheckAction(DataCheckActionCode.DROP_COL, metadata={"column": 'c'}).to_dict(),
                     DataCheckAction(DataCheckActionCode.DROP_COL, metadata={"column": 'd'}).to_dict()]
     }
-    # test X as ww.DataTable, y as ww.DataColumn
-    assert leakage_check.validate(ww.DataTable(X), ww.DataColumn(y)) == expected
+    # test X, y with ww
+    X_ww = X.copy()
+    X_ww.ww.init()
+    y_ww = ww.init_series(y)
+    assert leakage_check.validate(X_ww, y_ww) == expected
 
     # test y as list
     assert leakage_check.validate(X, y.values) == expected
@@ -238,8 +241,11 @@ def test_target_leakage_multi():
                     DataCheckAction(DataCheckActionCode.DROP_COL, metadata={"column": 'c'}).to_dict()]
     }
 
-    # test X as ww.DataTable, y as ww.DataColumn
-    assert leakage_check.validate(ww.DataTable(X), ww.DataColumn(y)) == expected
+    # test X, y with ww
+    X_ww = X.copy()
+    X_ww.ww.init()
+    y_ww = ww.init_series(y)
+    assert leakage_check.validate(X_ww, y_ww) == expected
 
     #  test y as list
     assert leakage_check.validate(X, y.values) == expected
@@ -283,8 +289,11 @@ def test_target_leakage_regression():
                     DataCheckAction(DataCheckActionCode.DROP_COL, metadata={"column": 'e'}).to_dict()]
     }
 
-    # test X as ww.DataTable, y as ww.DataColumn
-    assert leakage_check.validate(ww.DataTable(X), ww.DataColumn(y)) == expected
+    # test X, y with ww
+    X_ww = X.copy()
+    X_ww.ww.init()
+    y_ww = ww.init_series(y)
+    assert leakage_check.validate(X_ww, y_ww) == expected
 
     #  test y as list
     assert leakage_check.validate(X, y.values) == expected
@@ -398,8 +407,11 @@ def test_target_leakage_data_check_input_formats_pearson():
                     DataCheckAction(DataCheckActionCode.DROP_COL, metadata={"column": 3}).to_dict()]
     }
 
-    # test X as ww.DataTable, y as ww.DataColumn
-    assert leakage_check.validate(ww.DataTable(X), ww.DataColumn(y)) == expected
+    # test X, y with ww
+    X_ww = X.copy()
+    X_ww.ww.init()
+    y_ww = ww.init_series(y)
+    assert leakage_check.validate(X_ww, y_ww) == expected
 
     #  test y as list
     assert leakage_check.validate(X, y.values) == expected
