@@ -8,6 +8,7 @@ import woodwork as ww
 
 from evalml.exceptions import PipelineScoreError
 from evalml.model_understanding.prediction_explanations.explainers import (
+    ExplainPredictionsStage,
     abs_error,
     cross_entropy,
     explain_predictions,
@@ -402,7 +403,8 @@ def test_explain_predictions_best_worst_and_explain_predictions(mock_make_table,
     input_features = pd.DataFrame({"a": [3, 4]}, index=custom_index)
     pipeline.problem_type = problem_type
     pipeline.name = "Test Pipeline Name"
-    pipeline.compute_estimator_features.return_value = ww.DataTable(input_features)
+    input_features.ww.init()
+    pipeline.compute_estimator_features.return_value = input_features
 
     def _add_custom_index(answer, index_best, index_worst, output_format):
 
@@ -421,7 +423,7 @@ def test_explain_predictions_best_worst_and_explain_predictions(mock_make_table,
         abs_error_mock = MagicMock(__name__="abs_error")
         abs_error_mock.return_value = pd.Series([4., 1.], dtype="float64")
         mock_default_metrics.__getitem__.return_value = abs_error_mock
-        pipeline.predict.return_value = ww.DataColumn(pd.Series([2, 1]))
+        pipeline.predict.return_value = ww.init_series(pd.Series([2, 1]))
         y_true = pd.Series([3, 2], index=custom_index)
         answer = _add_custom_index(answer, index_best=custom_index[1],
                                    index_worst=custom_index[0], output_format=output_format)
@@ -430,8 +432,10 @@ def test_explain_predictions_best_worst_and_explain_predictions(mock_make_table,
         cross_entropy_mock = MagicMock(__name__="cross_entropy")
         mock_default_metrics.__getitem__.return_value = cross_entropy_mock
         cross_entropy_mock.return_value = pd.Series([0.2, 0.78])
-        pipeline.predict_proba.return_value = ww.DataTable(pd.DataFrame({"benign": [0.05, 0.1], "malignant": [0.95, 0.9]}))
-        pipeline.predict.return_value = ww.DataColumn(pd.Series(["malignant"] * 2))
+        proba = pd.DataFrame({"benign": [0.05, 0.1], "malignant": [0.95, 0.9]})
+        proba.ww.init()
+        pipeline.predict_proba.return_value = proba
+        pipeline.predict.return_value = ww.init_series(pd.Series(["malignant"] * 2))
         y_true = pd.Series(["malignant", "benign"], index=custom_index)
         answer = _add_custom_index(answer, index_best=custom_index[0],
                                    index_worst=custom_index[1], output_format=output_format)
@@ -443,9 +447,10 @@ def test_explain_predictions_best_worst_and_explain_predictions(mock_make_table,
         cross_entropy_mock = MagicMock(__name__="cross_entropy")
         mock_default_metrics.__getitem__.return_value = cross_entropy_mock
         cross_entropy_mock.return_value = pd.Series([0.15, 0.34])
-        pipeline.predict_proba.return_value = ww.DataTable(pd.DataFrame({"setosa": [0.8, 0.2], "versicolor": [0.1, 0.75],
-                                                                         "virginica": [0.1, 0.05]}))
-        pipeline.predict.return_value = ww.DataColumn(pd.Series(["setosa", "versicolor"]))
+        proba = pd.DataFrame({"setosa": [0.8, 0.2], "versicolor": [0.1, 0.75], "virginica": [0.1, 0.05]})
+        proba.ww.init()
+        pipeline.predict_proba.return_value = proba
+        pipeline.predict.return_value = ww.init_series(pd.Series(["setosa", "versicolor"]))
         y_true = pd.Series(["setosa", "versicolor"], index=custom_index)
         answer = _add_custom_index(answer, index_best=custom_index[0],
                                    index_worst=custom_index[1], output_format=output_format)
@@ -525,9 +530,10 @@ def test_explain_predictions_best_worst_custom_metric(mock_make_table, output_fo
     input_features = pd.DataFrame({"a": [5, 6]})
     pipeline.problem_type = ProblemTypes.REGRESSION
     pipeline.name = "Test Pipeline Name"
-    pipeline.compute_estimator_features.return_value = ww.DataTable(input_features)
+    input_features.ww.init()
+    pipeline.compute_estimator_features.return_value = input_features
 
-    pipeline.predict.return_value = ww.DataColumn(pd.Series([2, 1]))
+    pipeline.predict.return_value = ww.init_series(pd.Series([2, 1]))
     y_true = pd.Series([3, 2])
 
     def sum(y_true, y_pred):
@@ -651,7 +657,6 @@ pipeline_test_cases = [(BinaryClassificationPipeline, "Random Forest Classifier"
 @pytest.mark.parametrize("pipeline_class,estimator", pipeline_test_cases)
 def test_categories_aggregated_linear_pipeline(pipeline_class, estimator, fraud_100):
     X, y = fraud_100
-    y = y.to_series()
 
     pipeline = pipeline_class(component_graph=["Select Columns Transformer", "One Hot Encoder", "DateTime Featurization Component", estimator],
                               parameters={"Select Columns Transformer": {'columns': ['amount', 'provider', "currency"]},
@@ -673,8 +678,8 @@ def test_categories_aggregated_linear_pipeline(pipeline_class, estimator, fraud_
 @pytest.mark.parametrize("pipeline_class,estimator", pipeline_test_cases)
 def test_categories_aggregated_text(pipeline_class, estimator, fraud_100):
     X, y = fraud_100
-    y = y.to_series()
-    X = X.set_types(logical_types={'provider': 'NaturalLanguage'})
+
+    X.ww.set_types(logical_types={'provider': 'NaturalLanguage'})
     component_graph = ["Select Columns Transformer", "One Hot Encoder", "Text Featurization Component", "DateTime Featurization Component", estimator]
 
     pipeline = pipeline_class(component_graph,
@@ -698,7 +703,6 @@ def test_categories_aggregated_text(pipeline_class, estimator, fraud_100):
 @pytest.mark.parametrize("pipeline_class,estimator", pipeline_test_cases)
 def test_categories_aggregated_date_ohe(pipeline_class, estimator, fraud_100):
     X, y = fraud_100
-    y = y.to_series()
 
     pipeline = pipeline_class(component_graph=["Select Columns Transformer", "DateTime Featurization Component",
                                                "One Hot Encoder", estimator],
@@ -722,7 +726,6 @@ def test_categories_aggregated_date_ohe(pipeline_class, estimator, fraud_100):
 @pytest.mark.parametrize("pipeline_class,estimator", pipeline_test_cases)
 def test_categories_aggregated_pca_dag(pipeline_class, estimator, fraud_100):
     X, y = fraud_100
-    y = y.to_series()
 
     component_graph = {
         'SelectNumeric': ["Select Columns Transformer"],
@@ -757,7 +760,6 @@ def test_categories_aggregated_pca_dag(pipeline_class, estimator, fraud_100):
 @pytest.mark.parametrize("pipeline_class,estimator", pipeline_test_cases)
 def test_categories_aggregated_but_not_those_that_are_dropped(pipeline_class, estimator, fraud_100):
     X, y = fraud_100
-    y = y.to_series()
 
     component_graph = ["Select Columns Transformer", "One Hot Encoder",
                        "DateTime Featurization Component", 'Drop Columns Transformer', estimator]
@@ -783,7 +785,6 @@ def test_categories_aggregated_but_not_those_that_are_dropped(pipeline_class, es
 @pytest.mark.parametrize("pipeline_class,estimator", pipeline_test_cases)
 def test_categories_aggregated_when_some_are_dropped(pipeline_class, estimator, fraud_100):
     X, y = fraud_100
-    y = y.to_series()
 
     component_graph = ["Select Columns Transformer", "One Hot Encoder", "DateTime Featurization Component", 'Drop Columns Transformer', estimator]
     parameters = {"Select Columns Transformer": {'columns': ['amount', 'provider', "currency",
@@ -835,3 +836,30 @@ def test_explain_predictions_oversampler(estimator, fraud_100):
     report = explain_predictions(pipeline, X, y, indices_to_explain=[0], output_format="dataframe", top_k_features=4)
     assert report['feature_names'].isnull().sum() == 0
     assert report['feature_values'].isnull().sum() == 0
+
+
+@patch("evalml.model_understanding.prediction_explanations._user_interface._make_single_prediction_shap_table")
+def test_explain_predictions_best_worst_callback(mock_make_table):
+    pipeline = MagicMock()
+    pipeline.parameters = "Mock parameters"
+    input_features = pd.DataFrame({"a": [5, 6]})
+    pipeline.problem_type = ProblemTypes.REGRESSION
+    pipeline.name = "Test Pipeline Name"
+    input_features.ww.init()
+    pipeline.compute_estimator_features.return_value = input_features
+    pipeline.predict.return_value = ww.init_series(pd.Series([2, 1]))
+    y_true = pd.Series([3, 2])
+
+    class MockCallback:
+        def __init__(self):
+            self.progress_stages = []
+            self.total_elapsed_time = 0
+
+        def __call__(self, progress_stage, time_elapsed):
+            self.progress_stages.append(progress_stage)
+            self.total_elapsed_time = time_elapsed
+
+    mock_callback = MockCallback()
+    explain_predictions_best_worst(pipeline, input_features, y_true, num_to_explain=1, callback=mock_callback)
+    assert mock_callback.progress_stages == [e for e in ExplainPredictionsStage]
+    assert mock_callback.total_elapsed_time > 0
