@@ -32,8 +32,8 @@ def test_cbm_objective_automl(optimize_thresholds, X_y_binary):
     pipeline = automl.best_pipeline
     pipeline.fit(X, y)
     predictions = pipeline.predict(X, cbm)
-    assert not np.isnan(predictions.to_series()).values.any()
-    assert not np.isnan(pipeline.predict_proba(X).to_dataframe()).values.any()
+    assert not np.isnan(predictions).values.any()
+    assert not np.isnan(pipeline.predict_proba(X)).values.any()
     assert not np.isnan(pipeline.score(X, y, [cbm])['Cost Benefit Matrix'])
 
 
