@@ -6,7 +6,8 @@ from evalml import AutoMLSearch
 from evalml.objectives import LeadScoring
 
 
-def test_lead_scoring_objective(X_y_binary):
+def test_lead_scoring_works_during_automl_search(X_y_binary):
+
     X, y = X_y_binary
 
     objective = LeadScoring(true_positives=1,
@@ -21,6 +22,12 @@ def test_lead_scoring_objective(X_y_binary):
     pipeline.predict_proba(X)
     pipeline.score(X, y, [objective])
 
+
+def test_lead_scoring_objective():
+
+    objective = LeadScoring(true_positives=1,
+                            false_positives=-1)
+
     predicted = pd.Series([1, 10, .5, 5])
     out = objective.decision_function(predicted, 1)
     y_true = pd.Series([False, True, False, True])
