@@ -78,11 +78,17 @@ def test_binary_init():
 
 @patch('evalml.pipelines.ClassificationPipeline._decode_targets', return_value=[0, 1])
 @patch('evalml.objectives.BinaryClassificationObjective.decision_function', return_value=pd.Series([1, 0]))
-@patch('evalml.pipelines.components.Estimator.predict_proba', return_value=ww.DataTable(pd.DataFrame([[0.1, 0.2], [0.1, 0.2]])))
-@patch('evalml.pipelines.components.Estimator.predict', return_value=ww.DataColumn(pd.Series([1, 0])))
+@patch('evalml.pipelines.components.Estimator.predict_proba')
+@patch('evalml.pipelines.components.Estimator.predict')
 def test_binary_classification_pipeline_predict(mock_predict, mock_predict_proba,
                                                 mock_obj_decision, mock_decode,
                                                 X_y_binary, dummy_binary_pipeline_class):
+    proba = pd.DataFrame([[0.1, 0.2], [0.1, 0.2]])
+    proba.ww.init()
+    predict = ww.init_series(pd.Series([1, 0]))
+    mock_predict.return_value = predict
+    mock_predict_proba.return_value = proba
+
     mock_objs = [mock_decode, mock_predict]
     X, y = X_y_binary
     binary_pipeline = dummy_binary_pipeline_class(parameters={"Logistic Regression Classifier": {"n_jobs": 1}})
