@@ -27,7 +27,7 @@ def test_new_unique_targets_in_score(X_y_binary, logistic_regression_binary_pipe
 def test_pipeline_has_classes_property(logistic_regression_binary_pipeline_class,
                                        logistic_regression_multiclass_pipeline_class, problem_type, use_ints):
     if problem_type == "binary":
-        X, y = load_breast_cancer(return_pandas=True)
+        X, y = load_breast_cancer()
         pipeline = logistic_regression_binary_pipeline_class(parameters={"Logistic Regression Classifier": {"n_jobs": 1}})
         if use_ints:
             y = y.map({'malignant': 0, 'benign': 1})
@@ -35,7 +35,7 @@ def test_pipeline_has_classes_property(logistic_regression_binary_pipeline_class
         else:
             answer = ["benign", "malignant"]
     elif problem_type == "multi":
-        X, y = load_wine(return_pandas=True)
+        X, y = load_wine()
         pipeline = logistic_regression_multiclass_pipeline_class(parameters={"Logistic Regression Classifier": {"n_jobs": 1}})
         if use_ints:
             y = y.map({"class_0": 0, "class_1": 1, "class_2": 2})
@@ -54,5 +54,5 @@ def test_woodwork_classification_pipeline(logistic_regression_binary_pipeline_cl
     X, y = load_breast_cancer()
     mock_pipeline = logistic_regression_binary_pipeline_class(parameters={"Logistic Regression Classifier": {"n_jobs": 1}})
     mock_pipeline.fit(X, y)
-    assert not pd.isnull(mock_pipeline.predict(X).to_series()).any()
-    assert not pd.isnull(mock_pipeline.predict_proba(X).to_dataframe()).any().any()
+    assert not pd.isnull(mock_pipeline.predict(X)).any()
+    assert not pd.isnull(mock_pipeline.predict_proba(X)).any().any()
