@@ -121,7 +121,7 @@ def test_predict_pad_nans(mock_decode_targets,
                                     "pipeline": {"date_index": None, "gap": gap, "max_delay": max_delay}})
 
     def mock_predict(df, y=None):
-        return ww.DataColumn(pd.Series(range(200, 200 + df.shape[0])))
+        return pd.Series(range(200, 200 + df.shape[0]))
 
     if isinstance(pl, TimeSeriesRegressionPipeline):
         mock_regressor_predict.side_effect = mock_predict
@@ -137,9 +137,9 @@ def test_predict_pad_nans(mock_decode_targets,
 
     # Check that the predictions have NaNs for the first n_delay dates
     if include_delayed_features:
-        assert np.isnan(preds.to_series().values[:max_delay]).all()
+        assert np.isnan(preds.values[:max_delay]).all()
     else:
-        assert not np.isnan(preds.to_series().values).any()
+        assert not np.isnan(preds.values).any()
 
 
 @pytest.mark.parametrize("only_use_y", [True, False])
@@ -182,7 +182,7 @@ def test_score_drops_nans(mock_binary_score, mock_score, mock_encode_targets,
                                     "pipeline": {"date_index": None, "gap": gap, "max_delay": max_delay}})
 
     def mock_predict(X, y=None):
-        return ww.DataColumn(pd.Series(range(200, 200 + X.shape[0])))
+        return pd.Series(range(200, 200 + X.shape[0]))
 
     if isinstance(pl, TimeSeriesRegressionPipeline):
         mock_regressor_predict.side_effect = mock_predict
@@ -218,9 +218,12 @@ def test_classification_pipeline_encodes_targets(mock_encode, mock_decode,
                                                  mock_fit, pipeline_class, X_y_binary):
     X, y = X_y_binary
     y_series = pd.Series(y)
-    mock_predict.return_value = ww.DataColumn(y_series)
-    mock_predict_proba.return_value = ww.DataTable(pd.DataFrame({"negative": y_series,
-                                                                 "positive": y_series}))
+    df = pd.DataFrame({"negative": y_series,
+                       "positive": y_series})
+    df.ww.init()
+    mock_predict.return_value = ww.init_series(y_series)
+    mock_predict_proba.return_value = df
+
     X = pd.DataFrame({"feature": range(len(y))})
     y_encoded = y_series.map(lambda label: "positive" if label == 1 else "negative")
 
@@ -294,14 +297,14 @@ def test_score_works(pipeline_class, objectives, data_type, X_y_binary, X_y_mult
     pl.fit(X, y)
     if expected_unique_values:
         # NaNs are expected because of padding due to max_delay
-        assert set(pl.predict(X, y).to_series().dropna().unique()) == expected_unique_values
+        assert set(pl.predict(X, y).dropna().unique()) == expected_unique_values
     pl.score(X, y, objectives)
 
 
 @patch('evalml.pipelines.TimeSeriesClassificationPipeline._decode_targets')
 @patch('evalml.objectives.BinaryClassificationObjective.decision_function')
-@patch('evalml.pipelines.components.Estimator.predict_proba', return_value=ww.DataTable(pd.DataFrame({0: [1.]})))
-@patch('evalml.pipelines.components.Estimator.predict', return_value=ww.DataColumn(pd.Series([1.])))
+@patch('evalml.pipelines.components.Estimator.predict_proba', return_value=pd.DataFrame({0: [1.]}))
+@patch('evalml.pipelines.components.Estimator.predict', return_value=pd.Series([1.]))
 def test_binary_classification_predictions_thresholded_properly(mock_predict, mock_predict_proba,
                                                                 mock_obj_decision, mock_decode,
                                                                 X_y_binary, dummy_ts_binary_pipeline_class):
@@ -325,7 +328,7 @@ def test_binary_classification_predictions_thresholded_properly(mock_predict, mo
 
     mock_objs = [mock_decode, mock_predict_proba]
     # test custom threshold set but no objective passed
-    mock_predict_proba.return_value = ww.DataTable(pd.DataFrame([[0.1, 0.2], [0.1, 0.2]]))
+    mock_predict_proba.return_value = pd.DataFrame([[0.1, 0.2], [0.1, 0.2]])
     binary_pipeline.threshold = 0.6
     binary_pipeline._encoder.classes_ = [0, 1]
     binary_pipeline.predict(X, y)
